# coding: utf-8

"""
    ThingsBoard REST API

     ThingsBoard open-source IoT platform REST API documentation.  # noqa: E501

    OpenAPI spec version: 3.6.2
    Contact: info@thingsboard.io
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

#  Copyright 2024. ThingsBoard
#
#  Licensed under the Apache License, Version 2.0 (the "License");
#  you may not use this file except in compliance with the License.
#  You may obtain a copy of the License at
#
#   http://www.apache.org/licenses/LICENSE-2.0
#
#  Unless required by applicable law or agreed to in writing, software
#  distributed under the License is distributed on an "AS IS" BASIS,
#  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
#  See the License for the specific language governing permissions and
#  limitations under the License.

import pprint
import re  # noqa: F401

import six

class TenantProfile(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'default': 'bool',
        'id': 'TenantProfileId',
        'created_time': 'int',
        'name': 'str',
        'description': 'str',
        'isolated_tb_rule_engine': 'bool',
        'profile_data': 'TenantProfileData'
    }

    attribute_map = {
        'default': 'default',
        'id': 'id',
        'created_time': 'createdTime',
        'name': 'name',
        'description': 'description',
        'isolated_tb_rule_engine': 'isolatedTbRuleEngine',
        'profile_data': 'profileData'
    }

    def __init__(self, default=None, id=None, created_time=None, name=None, description=None, isolated_tb_rule_engine=None, profile_data=None):  # noqa: E501
        """TenantProfile - a model defined in Swagger"""  # noqa: E501
        self._default = None
        self._id = None
        self._created_time = None
        self._name = None
        self._description = None
        self._isolated_tb_rule_engine = None
        self._profile_data = None
        self.discriminator = None
        if default is not None:
            self.default = default
        if id is not None:
            self.id = id
        if created_time is not None:
            self.created_time = created_time
        if name is not None:
            self.name = name
        if description is not None:
            self.description = description
        if isolated_tb_rule_engine is not None:
            self.isolated_tb_rule_engine = isolated_tb_rule_engine
        if profile_data is not None:
            self.profile_data = profile_data

    @property
    def default(self):
        """Gets the default of this TenantProfile.  # noqa: E501


        :return: The default of this TenantProfile.  # noqa: E501
        :rtype: bool
        """
        return self._default

    @default.setter
    def default(self, default):
        """Sets the default of this TenantProfile.


        :param default: The default of this TenantProfile.  # noqa: E501
        :type: bool
        """

        self._default = default

    @property
    def id(self):
        """Gets the id of this TenantProfile.  # noqa: E501


        :return: The id of this TenantProfile.  # noqa: E501
        :rtype: TenantProfileId
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this TenantProfile.


        :param id: The id of this TenantProfile.  # noqa: E501
        :type: TenantProfileId
        """

        self._id = id

    @property
    def created_time(self):
        """Gets the created_time of this TenantProfile.  # noqa: E501

        Timestamp of the tenant profile creation, in milliseconds  # noqa: E501

        :return: The created_time of this TenantProfile.  # noqa: E501
        :rtype: int
        """
        return self._created_time

    @created_time.setter
    def created_time(self, created_time):
        """Sets the created_time of this TenantProfile.

        Timestamp of the tenant profile creation, in milliseconds  # noqa: E501

        :param created_time: The created_time of this TenantProfile.  # noqa: E501
        :type: int
        """

        self._created_time = created_time

    @property
    def name(self):
        """Gets the name of this TenantProfile.  # noqa: E501

        Name of the tenant profile  # noqa: E501

        :return: The name of this TenantProfile.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this TenantProfile.

        Name of the tenant profile  # noqa: E501

        :param name: The name of this TenantProfile.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def description(self):
        """Gets the description of this TenantProfile.  # noqa: E501

        Description of the tenant profile  # noqa: E501

        :return: The description of this TenantProfile.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this TenantProfile.

        Description of the tenant profile  # noqa: E501

        :param description: The description of this TenantProfile.  # noqa: E501
        :type: str
        """

        self._description = description

    @property
    def isolated_tb_rule_engine(self):
        """Gets the isolated_tb_rule_engine of this TenantProfile.  # noqa: E501

        If enabled, will push all messages related to this tenant and processed by the rule engine into separate queue. Useful for complex microservices deployments, to isolate processing of the data for specific tenants  # noqa: E501

        :return: The isolated_tb_rule_engine of this TenantProfile.  # noqa: E501
        :rtype: bool
        """
        return self._isolated_tb_rule_engine

    @isolated_tb_rule_engine.setter
    def isolated_tb_rule_engine(self, isolated_tb_rule_engine):
        """Sets the isolated_tb_rule_engine of this TenantProfile.

        If enabled, will push all messages related to this tenant and processed by the rule engine into separate queue. Useful for complex microservices deployments, to isolate processing of the data for specific tenants  # noqa: E501

        :param isolated_tb_rule_engine: The isolated_tb_rule_engine of this TenantProfile.  # noqa: E501
        :type: bool
        """

        self._isolated_tb_rule_engine = isolated_tb_rule_engine

    @property
    def profile_data(self):
        """Gets the profile_data of this TenantProfile.  # noqa: E501


        :return: The profile_data of this TenantProfile.  # noqa: E501
        :rtype: TenantProfileData
        """
        return self._profile_data

    @profile_data.setter
    def profile_data(self, profile_data):
        """Sets the profile_data of this TenantProfile.


        :param profile_data: The profile_data of this TenantProfile.  # noqa: E501
        :type: TenantProfileData
        """

        self._profile_data = profile_data

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(TenantProfile, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, TenantProfile):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    ThingsBoard REST API

     ThingsBoard Professional Edition IoT platform REST API documentation.  # noqa: E501

    OpenAPI spec version: 3.6.2PE
    Contact: info@thingsboard.io
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

#  Copyright 2024. ThingsBoard
#
#  Licensed under the Apache License, Version 2.0 (the "License");
#  you may not use this file except in compliance with the License.
#  You may obtain a copy of the License at
#
#   http://www.apache.org/licenses/LICENSE-2.0
#
#  Unless required by applicable law or agreed to in writing, software
#  distributed under the License is distributed on an "AS IS" BASIS,
#  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
#  See the License for the specific language governing permissions and
#  limitations under the License.

import pprint
import re  # noqa: F401

import six

class RuleChainOutputLabelsUsage(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'rule_chain_id': 'RuleChainId',
        'rule_node_id': 'RuleNodeId',
        'rule_chain_name': 'str',
        'rule_node_name': 'str',
        'labels': 'list[str]'
    }

    attribute_map = {
        'rule_chain_id': 'ruleChainId',
        'rule_node_id': 'ruleNodeId',
        'rule_chain_name': 'ruleChainName',
        'rule_node_name': 'ruleNodeName',
        'labels': 'labels'
    }

    def __init__(self, rule_chain_id=None, rule_node_id=None, rule_chain_name=None, rule_node_name=None, labels=None):  # noqa: E501
        """RuleChainOutputLabelsUsage - a model defined in Swagger"""  # noqa: E501
        self._rule_chain_id = None
        self._rule_node_id = None
        self._rule_chain_name = None
        self._rule_node_name = None
        self._labels = None
        self.discriminator = None
        self.rule_chain_id = rule_chain_id
        self.rule_node_id = rule_node_id
        self.rule_chain_name = rule_chain_name
        self.rule_node_name = rule_node_name
        self.labels = labels

    @property
    def rule_chain_id(self):
        """Gets the rule_chain_id of this RuleChainOutputLabelsUsage.  # noqa: E501


        :return: The rule_chain_id of this RuleChainOutputLabelsUsage.  # noqa: E501
        :rtype: RuleChainId
        """
        return self._rule_chain_id

    @rule_chain_id.setter
    def rule_chain_id(self, rule_chain_id):
        """Sets the rule_chain_id of this RuleChainOutputLabelsUsage.


        :param rule_chain_id: The rule_chain_id of this RuleChainOutputLabelsUsage.  # noqa: E501
        :type: RuleChainId
        """
        if rule_chain_id is None:
            raise ValueError("Invalid value for `rule_chain_id`, must not be `None`")  # noqa: E501

        self._rule_chain_id = rule_chain_id

    @property
    def rule_node_id(self):
        """Gets the rule_node_id of this RuleChainOutputLabelsUsage.  # noqa: E501


        :return: The rule_node_id of this RuleChainOutputLabelsUsage.  # noqa: E501
        :rtype: RuleNodeId
        """
        return self._rule_node_id

    @rule_node_id.setter
    def rule_node_id(self, rule_node_id):
        """Sets the rule_node_id of this RuleChainOutputLabelsUsage.


        :param rule_node_id: The rule_node_id of this RuleChainOutputLabelsUsage.  # noqa: E501
        :type: RuleNodeId
        """
        if rule_node_id is None:
            raise ValueError("Invalid value for `rule_node_id`, must not be `None`")  # noqa: E501

        self._rule_node_id = rule_node_id

    @property
    def rule_chain_name(self):
        """Gets the rule_chain_name of this RuleChainOutputLabelsUsage.  # noqa: E501

        Rule Chain Name  # noqa: E501

        :return: The rule_chain_name of this RuleChainOutputLabelsUsage.  # noqa: E501
        :rtype: str
        """
        return self._rule_chain_name

    @rule_chain_name.setter
    def rule_chain_name(self, rule_chain_name):
        """Sets the rule_chain_name of this RuleChainOutputLabelsUsage.

        Rule Chain Name  # noqa: E501

        :param rule_chain_name: The rule_chain_name of this RuleChainOutputLabelsUsage.  # noqa: E501
        :type: str
        """
        if rule_chain_name is None:
            raise ValueError("Invalid value for `rule_chain_name`, must not be `None`")  # noqa: E501

        self._rule_chain_name = rule_chain_name

    @property
    def rule_node_name(self):
        """Gets the rule_node_name of this RuleChainOutputLabelsUsage.  # noqa: E501

        Rule Node Name  # noqa: E501

        :return: The rule_node_name of this RuleChainOutputLabelsUsage.  # noqa: E501
        :rtype: str
        """
        return self._rule_node_name

    @rule_node_name.setter
    def rule_node_name(self, rule_node_name):
        """Sets the rule_node_name of this RuleChainOutputLabelsUsage.

        Rule Node Name  # noqa: E501

        :param rule_node_name: The rule_node_name of this RuleChainOutputLabelsUsage.  # noqa: E501
        :type: str
        """
        if rule_node_name is None:
            raise ValueError("Invalid value for `rule_node_name`, must not be `None`")  # noqa: E501

        self._rule_node_name = rule_node_name

    @property
    def labels(self):
        """Gets the labels of this RuleChainOutputLabelsUsage.  # noqa: E501

        Output labels  # noqa: E501

        :return: The labels of this RuleChainOutputLabelsUsage.  # noqa: E501
        :rtype: list[str]
        """
        return self._labels

    @labels.setter
    def labels(self, labels):
        """Sets the labels of this RuleChainOutputLabelsUsage.

        Output labels  # noqa: E501

        :param labels: The labels of this RuleChainOutputLabelsUsage.  # noqa: E501
        :type: list[str]
        """
        if labels is None:
            raise ValueError("Invalid value for `labels`, must not be `None`")  # noqa: E501

        self._labels = labels

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(RuleChainOutputLabelsUsage, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, RuleChainOutputLabelsUsage):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    ThingsBoard REST API

     ThingsBoard Professional Edition IoT platform REST API documentation.  # noqa: E501

    OpenAPI spec version: 3.6.2PE
    Contact: info@thingsboard.io
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

#  Copyright 2024. ThingsBoard
#
#  Licensed under the Apache License, Version 2.0 (the "License");
#  you may not use this file except in compliance with the License.
#  You may obtain a copy of the License at
#
#   http://www.apache.org/licenses/LICENSE-2.0
#
#  Unless required by applicable law or agreed to in writing, software
#  distributed under the License is distributed on an "AS IS" BASIS,
#  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
#  See the License for the specific language governing permissions and
#  limitations under the License.

from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from tb_rest_client.api_client import ApiClient


class ReportControllerApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def download_dashboard_report_using_post(self, dashboard_id, **kwargs):  # noqa: E501
        """downloadDashboardReport  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.download_dashboard_report_using_post(dashboard_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str dashboard_id: dashboardId (required)
        :param JsonNode body:
        :return: DeferredResultResponseEntity
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.download_dashboard_report_using_post_with_http_info(dashboard_id, **kwargs)  # noqa: E501
        else:
            (data) = self.download_dashboard_report_using_post_with_http_info(dashboard_id, **kwargs)  # noqa: E501
            return data

    def download_dashboard_report_using_post_with_http_info(self, dashboard_id, **kwargs):  # noqa: E501
        """downloadDashboardReport  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.download_dashboard_report_using_post_with_http_info(dashboard_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str dashboard_id: dashboardId (required)
        :param JsonNode body:
        :return: DeferredResultResponseEntity
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['dashboard_id', 'body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method download_dashboard_report_using_post" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'dashboard_id' is set
        if ('dashboard_id' not in params or
                params['dashboard_id'] is None):
            raise ValueError("Missing the required parameter `dashboard_id` when calling `download_dashboard_report_using_post`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'dashboard_id' in params:
            path_params['dashboardId'] = params['dashboard_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['X-Authorization']  # noqa: E501

        return self.api_client.call_api(
            '/api/report/{dashboardId}/download', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='DeferredResultResponseEntity',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def download_test_report_using_post(self, **kwargs):  # noqa: E501
        """downloadTestReport  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.download_test_report_using_post(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param ReportConfig body:
        :param str reports_server_endpoint_url: reportsServerEndpointUrl
        :return: DeferredResultResponseEntity
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.download_test_report_using_post_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.download_test_report_using_post_with_http_info(**kwargs)  # noqa: E501
            return data

    def download_test_report_using_post_with_http_info(self, **kwargs):  # noqa: E501
        """downloadTestReport  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.download_test_report_using_post_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param ReportConfig body:
        :param str reports_server_endpoint_url: reportsServerEndpointUrl
        :return: DeferredResultResponseEntity
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body', 'reports_server_endpoint_url']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method download_test_report_using_post" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'reports_server_endpoint_url' in params:
            query_params.append(('reportsServerEndpointUrl', params['reports_server_endpoint_url']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['X-Authorization']  # noqa: E501

        return self.api_client.call_api(
            '/api/report/test{?reportsServerEndpointUrl}', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='DeferredResultResponseEntity',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    ThingsBoard REST API

     ThingsBoard Professional Edition IoT platform REST API documentation.  # noqa: E501

    OpenAPI spec version: 3.6.2PE
    Contact: info@thingsboard.io
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

#  Copyright 2024. ThingsBoard
#
#  Licensed under the Apache License, Version 2.0 (the "License");
#  you may not use this file except in compliance with the License.
#  You may obtain a copy of the License at
#
#   http://www.apache.org/licenses/LICENSE-2.0
#
#  Unless required by applicable law or agreed to in writing, software
#  distributed under the License is distributed on an "AS IS" BASIS,
#  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
#  See the License for the specific language governing permissions and
#  limitations under the License.

import pprint
import re  # noqa: F401

import six
from tb_rest_client.models.models_ce.notification_target_config import NotificationTargetConfig  # noqa: F401,E501

class SlackNotificationTargetConfig(NotificationTargetConfig):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'conversation': 'SlackConversation',
        'conversation_type': 'str',
        'description': 'str'
    }
    if hasattr(NotificationTargetConfig, "swagger_types"):
        swagger_types.update(NotificationTargetConfig.swagger_types)

    attribute_map = {
        'conversation': 'conversation',
        'conversation_type': 'conversationType',
        'description': 'description'
    }
    if hasattr(NotificationTargetConfig, "attribute_map"):
        attribute_map.update(NotificationTargetConfig.attribute_map)

    def __init__(self, conversation=None, conversation_type=None, description=None, *args, **kwargs):  # noqa: E501
        """SlackNotificationTargetConfig - a model defined in Swagger"""  # noqa: E501
        self._conversation = None
        self._conversation_type = None
        self._description = None
        self.discriminator = None
        self.conversation = conversation
        if conversation_type is not None:
            self.conversation_type = conversation_type
        if description is not None:
            self.description = description
        NotificationTargetConfig.__init__(self, *args, **kwargs)

    @property
    def conversation(self):
        """Gets the conversation of this SlackNotificationTargetConfig.  # noqa: E501


        :return: The conversation of this SlackNotificationTargetConfig.  # noqa: E501
        :rtype: SlackConversation
        """
        return self._conversation

    @conversation.setter
    def conversation(self, conversation):
        """Sets the conversation of this SlackNotificationTargetConfig.


        :param conversation: The conversation of this SlackNotificationTargetConfig.  # noqa: E501
        :type: SlackConversation
        """
        if conversation is None:
            raise ValueError("Invalid value for `conversation`, must not be `None`")  # noqa: E501

        self._conversation = conversation

    @property
    def conversation_type(self):
        """Gets the conversation_type of this SlackNotificationTargetConfig.  # noqa: E501


        :return: The conversation_type of this SlackNotificationTargetConfig.  # noqa: E501
        :rtype: str
        """
        return self._conversation_type

    @conversation_type.setter
    def conversation_type(self, conversation_type):
        """Sets the conversation_type of this SlackNotificationTargetConfig.


        :param conversation_type: The conversation_type of this SlackNotificationTargetConfig.  # noqa: E501
        :type: str
        """
        allowed_values = ["DIRECT", "PRIVATE_CHANNEL", "PUBLIC_CHANNEL"]  # noqa: E501
        if conversation_type not in allowed_values:
            raise ValueError(
                "Invalid value for `conversation_type` ({0}), must be one of {1}"  # noqa: E501
                .format(conversation_type, allowed_values)
            )

        self._conversation_type = conversation_type

    @property
    def description(self):
        """Gets the description of this SlackNotificationTargetConfig.  # noqa: E501


        :return: The description of this SlackNotificationTargetConfig.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this SlackNotificationTargetConfig.


        :param description: The description of this SlackNotificationTargetConfig.  # noqa: E501
        :type: str
        """

        self._description = description

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(SlackNotificationTargetConfig, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, SlackNotificationTargetConfig):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    ThingsBoard REST API

     ThingsBoard Professional Edition IoT platform REST API documentation.  # noqa: E501

    OpenAPI spec version: 3.6.2PE
    Contact: info@thingsboard.io
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

#  Copyright 2024. ThingsBoard
#
#  Licensed under the Apache License, Version 2.0 (the "License");
#  you may not use this file except in compliance with the License.
#  You may obtain a copy of the License at
#
#   http://www.apache.org/licenses/LICENSE-2.0
#
#  Unless required by applicable law or agreed to in writing, software
#  distributed under the License is distributed on an "AS IS" BASIS,
#  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
#  See the License for the specific language governing permissions and
#  limitations under the License.

import pprint
import re  # noqa: F401

import six

class ResponseEntity(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'body': 'object',
        'status_code': 'str',
        'status_code_value': 'int'
    }

    attribute_map = {
        'body': 'body',
        'status_code': 'statusCode',
        'status_code_value': 'statusCodeValue'
    }

    def __init__(self, body=None, status_code=None, status_code_value=None):  # noqa: E501
        """ResponseEntity - a model defined in Swagger"""  # noqa: E501
        self._body = None
        self._status_code = None
        self._status_code_value = None
        self.discriminator = None
        if body is not None:
            self.body = body
        if status_code is not None:
            self.status_code = status_code
        if status_code_value is not None:
            self.status_code_value = status_code_value

    @property
    def body(self):
        """Gets the body of this ResponseEntity.  # noqa: E501


        :return: The body of this ResponseEntity.  # noqa: E501
        :rtype: object
        """
        return self._body

    @body.setter
    def body(self, body):
        """Sets the body of this ResponseEntity.


        :param body: The body of this ResponseEntity.  # noqa: E501
        :type: object
        """

        self._body = body

    @property
    def status_code(self):
        """Gets the status_code of this ResponseEntity.  # noqa: E501


        :return: The status_code of this ResponseEntity.  # noqa: E501
        :rtype: str
        """
        return self._status_code

    @status_code.setter
    def status_code(self, status_code):
        """Sets the status_code of this ResponseEntity.


        :param status_code: The status_code of this ResponseEntity.  # noqa: E501
        :type: str
        """
        allowed_values = ["ACCEPTED", "ALREADY_REPORTED", "BAD_GATEWAY", "BAD_REQUEST", "BANDWIDTH_LIMIT_EXCEEDED", "CHECKPOINT", "CONFLICT", "CONTINUE", "CREATED", "DESTINATION_LOCKED", "EXPECTATION_FAILED", "FAILED_DEPENDENCY", "FORBIDDEN", "FOUND", "GATEWAY_TIMEOUT", "GONE", "HTTP_VERSION_NOT_SUPPORTED", "IM_USED", "INSUFFICIENT_SPACE_ON_RESOURCE", "INSUFFICIENT_STORAGE", "INTERNAL_SERVER_ERROR", "I_AM_A_TEAPOT", "LENGTH_REQUIRED", "LOCKED", "LOOP_DETECTED", "METHOD_FAILURE", "METHOD_NOT_ALLOWED", "MOVED_PERMANENTLY", "MOVED_TEMPORARILY", "MULTIPLE_CHOICES", "MULTI_STATUS", "NETWORK_AUTHENTICATION_REQUIRED", "NON_AUTHORITATIVE_INFORMATION", "NOT_ACCEPTABLE", "NOT_EXTENDED", "NOT_FOUND", "NOT_IMPLEMENTED", "NOT_MODIFIED", "NO_CONTENT", "OK", "PARTIAL_CONTENT", "PAYLOAD_TOO_LARGE", "PAYMENT_REQUIRED", "PERMANENT_REDIRECT", "PRECONDITION_FAILED", "PRECONDITION_REQUIRED", "PROCESSING", "PROXY_AUTHENTICATION_REQUIRED", "REQUESTED_RANGE_NOT_SATISFIABLE", "REQUEST_ENTITY_TOO_LARGE", "REQUEST_HEADER_FIELDS_TOO_LARGE", "REQUEST_TIMEOUT", "REQUEST_URI_TOO_LONG", "RESET_CONTENT", "SEE_OTHER", "SERVICE_UNAVAILABLE", "SWITCHING_PROTOCOLS", "TEMPORARY_REDIRECT", "TOO_EARLY", "TOO_MANY_REQUESTS", "UNAUTHORIZED", "UNAVAILABLE_FOR_LEGAL_REASONS", "UNPROCESSABLE_ENTITY", "UNSUPPORTED_MEDIA_TYPE", "UPGRADE_REQUIRED", "URI_TOO_LONG", "USE_PROXY", "VARIANT_ALSO_NEGOTIATES"]  # noqa: E501
        if status_code not in allowed_values:
            raise ValueError(
                "Invalid value for `status_code` ({0}), must be one of {1}"  # noqa: E501
                .format(status_code, allowed_values)
            )

        self._status_code = status_code

    @property
    def status_code_value(self):
        """Gets the status_code_value of this ResponseEntity.  # noqa: E501


        :return: The status_code_value of this ResponseEntity.  # noqa: E501
        :rtype: int
        """
        return self._status_code_value

    @status_code_value.setter
    def status_code_value(self, status_code_value):
        """Sets the status_code_value of this ResponseEntity.


        :param status_code_value: The status_code_value of this ResponseEntity.  # noqa: E501
        :type: int
        """

        self._status_code_value = status_code_value

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(ResponseEntity, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ResponseEntity):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    ThingsBoard REST API

     ThingsBoard open-source IoT platform REST API documentation.  # noqa: E501

    OpenAPI spec version: 3.6.2
    Contact: info@thingsboard.io
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

#  Copyright 2024. ThingsBoard
#
#  Licensed under the Apache License, Version 2.0 (the "License");
#  you may not use this file except in compliance with the License.
#  You may obtain a copy of the License at
#
#   http://www.apache.org/licenses/LICENSE-2.0
#
#  Unless required by applicable law or agreed to in writing, software
#  distributed under the License is distributed on an "AS IS" BASIS,
#  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
#  See the License for the specific language governing permissions and
#  limitations under the License.

import pprint
import re  # noqa: F401

import six
from tb_rest_client.models.models_ce.entity_filter import EntityFilter  # noqa: F401,E501

class RelationsQueryFilter(EntityFilter):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'direction': 'str',
        'fetch_last_level_only': 'bool',
        'filters': 'list[RelationEntityTypeFilter]',
        'max_level': 'int',
        'multi_root': 'bool',
        'multi_root_entities_type': 'str',
        'multi_root_entity_ids': 'list[str]',
        'root_entity': 'EntityId'
    }
    if hasattr(EntityFilter, "swagger_types"):
        swagger_types.update(EntityFilter.swagger_types)

    attribute_map = {
        'direction': 'direction',
        'fetch_last_level_only': 'fetchLastLevelOnly',
        'filters': 'filters',
        'max_level': 'maxLevel',
        'multi_root': 'multiRoot',
        'multi_root_entities_type': 'multiRootEntitiesType',
        'multi_root_entity_ids': 'multiRootEntityIds',
        'root_entity': 'rootEntity'
    }
    if hasattr(EntityFilter, "attribute_map"):
        attribute_map.update(EntityFilter.attribute_map)

    def __init__(self, direction=None, fetch_last_level_only=None, filters=None, max_level=None, multi_root=None, multi_root_entities_type=None, multi_root_entity_ids=None, root_entity=None, *args, **kwargs):  # noqa: E501
        """RelationsQueryFilter - a model defined in Swagger"""  # noqa: E501
        self._direction = None
        self._fetch_last_level_only = None
        self._filters = None
        self._max_level = None
        self._multi_root = None
        self._multi_root_entities_type = None
        self._multi_root_entity_ids = None
        self._root_entity = None
        self.discriminator = None
        if direction is not None:
            self.direction = direction
        if fetch_last_level_only is not None:
            self.fetch_last_level_only = fetch_last_level_only
        if filters is not None:
            self.filters = filters
        if max_level is not None:
            self.max_level = max_level
        if multi_root is not None:
            self.multi_root = multi_root
        if multi_root_entities_type is not None:
            self.multi_root_entities_type = multi_root_entities_type
        if multi_root_entity_ids is not None:
            self.multi_root_entity_ids = multi_root_entity_ids
        if root_entity is not None:
            self.root_entity = root_entity
        EntityFilter.__init__(self, *args, **kwargs)

    @property
    def direction(self):
        """Gets the direction of this RelationsQueryFilter.  # noqa: E501


        :return: The direction of this RelationsQueryFilter.  # noqa: E501
        :rtype: str
        """
        return self._direction

    @direction.setter
    def direction(self, direction):
        """Sets the direction of this RelationsQueryFilter.


        :param direction: The direction of this RelationsQueryFilter.  # noqa: E501
        :type: str
        """
        allowed_values = ["FROM", "TO"]  # noqa: E501
        if direction not in allowed_values:
            raise ValueError(
                "Invalid value for `direction` ({0}), must be one of {1}"  # noqa: E501
                .format(direction, allowed_values)
            )

        self._direction = direction

    @property
    def fetch_last_level_only(self):
        """Gets the fetch_last_level_only of this RelationsQueryFilter.  # noqa: E501


        :return: The fetch_last_level_only of this RelationsQueryFilter.  # noqa: E501
        :rtype: bool
        """
        return self._fetch_last_level_only

    @fetch_last_level_only.setter
    def fetch_last_level_only(self, fetch_last_level_only):
        """Sets the fetch_last_level_only of this RelationsQueryFilter.


        :param fetch_last_level_only: The fetch_last_level_only of this RelationsQueryFilter.  # noqa: E501
        :type: bool
        """

        self._fetch_last_level_only = fetch_last_level_only

    @property
    def filters(self):
        """Gets the filters of this RelationsQueryFilter.  # noqa: E501


        :return: The filters of this RelationsQueryFilter.  # noqa: E501
        :rtype: list[RelationEntityTypeFilter]
        """
        return self._filters

    @filters.setter
    def filters(self, filters):
        """Sets the filters of this RelationsQueryFilter.


        :param filters: The filters of this RelationsQueryFilter.  # noqa: E501
        :type: list[RelationEntityTypeFilter]
        """

        self._filters = filters

    @property
    def max_level(self):
        """Gets the max_level of this RelationsQueryFilter.  # noqa: E501


        :return: The max_level of this RelationsQueryFilter.  # noqa: E501
        :rtype: int
        """
        return self._max_level

    @max_level.setter
    def max_level(self, max_level):
        """Sets the max_level of this RelationsQueryFilter.


        :param max_level: The max_level of this RelationsQueryFilter.  # noqa: E501
        :type: int
        """

        self._max_level = max_level

    @property
    def multi_root(self):
        """Gets the multi_root of this RelationsQueryFilter.  # noqa: E501


        :return: The multi_root of this RelationsQueryFilter.  # noqa: E501
        :rtype: bool
        """
        return self._multi_root

    @multi_root.setter
    def multi_root(self, multi_root):
        """Sets the multi_root of this RelationsQueryFilter.


        :param multi_root: The multi_root of this RelationsQueryFilter.  # noqa: E501
        :type: bool
        """

        self._multi_root = multi_root

    @property
    def multi_root_entities_type(self):
        """Gets the multi_root_entities_type of this RelationsQueryFilter.  # noqa: E501


        :return: The multi_root_entities_type of this RelationsQueryFilter.  # noqa: E501
        :rtype: str
        """
        return self._multi_root_entities_type

    @multi_root_entities_type.setter
    def multi_root_entities_type(self, multi_root_entities_type):
        """Sets the multi_root_entities_type of this RelationsQueryFilter.


        :param multi_root_entities_type: The multi_root_entities_type of this RelationsQueryFilter.  # noqa: E501
        :type: str
        """
        allowed_values = ["ALARM", "API_USAGE_STATE", "ASSET", "ASSET_PROFILE", "CUSTOMER", "DASHBOARD", "DEVICE", "DEVICE_PROFILE", "EDGE", "ENTITY_VIEW", "NOTIFICATION", "NOTIFICATION_REQUEST", "NOTIFICATION_RULE", "NOTIFICATION_TARGET", "NOTIFICATION_TEMPLATE", "OTA_PACKAGE", "QUEUE", "RPC", "RULE_CHAIN", "RULE_NODE", "TB_RESOURCE", "TENANT", "TENANT_PROFILE", "USER", "WIDGETS_BUNDLE", "WIDGET_TYPE"]  # noqa: E501
        if multi_root_entities_type not in allowed_values:
            raise ValueError(
                "Invalid value for `multi_root_entities_type` ({0}), must be one of {1}"  # noqa: E501
                .format(multi_root_entities_type, allowed_values)
            )

        self._multi_root_entities_type = multi_root_entities_type

    @property
    def multi_root_entity_ids(self):
        """Gets the multi_root_entity_ids of this RelationsQueryFilter.  # noqa: E501


        :return: The multi_root_entity_ids of this RelationsQueryFilter.  # noqa: E501
        :rtype: list[str]
        """
        return self._multi_root_entity_ids

    @multi_root_entity_ids.setter
    def multi_root_entity_ids(self, multi_root_entity_ids):
        """Sets the multi_root_entity_ids of this RelationsQueryFilter.


        :param multi_root_entity_ids: The multi_root_entity_ids of this RelationsQueryFilter.  # noqa: E501
        :type: list[str]
        """

        self._multi_root_entity_ids = multi_root_entity_ids

    @property
    def root_entity(self):
        """Gets the root_entity of this RelationsQueryFilter.  # noqa: E501


        :return: The root_entity of this RelationsQueryFilter.  # noqa: E501
        :rtype: EntityId
        """
        return self._root_entity

    @root_entity.setter
    def root_entity(self, root_entity):
        """Sets the root_entity of this RelationsQueryFilter.


        :param root_entity: The root_entity of this RelationsQueryFilter.  # noqa: E501
        :type: EntityId
        """

        self._root_entity = root_entity

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(RelationsQueryFilter, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, RelationsQueryFilter):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



#  Copyright 2024. ThingsBoard
#
#  Licensed under the Apache License, Version 2.0 (the "License");
#  you may not use this file except in compliance with the License.
#  You may obtain a copy of the License at
#
#   http://www.apache.org/licenses/LICENSE-2.0
#
#  Unless required by applicable law or agreed to in writing, software
#  distributed under the License is distributed on an "AS IS" BASIS,
#  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
#  See the License for the specific language governing permissions and
#  limitations under the License.

import unittest

from tb_rest_client.rest_client_ce import *
from tb_rest_client.rest_client_base import *
from tb_rest_client.models.models_ce import *


TB_URL_CE = 'http://0.0.0.0:8080'

TB_TENANT_USERNAME_CE = 'tenant@thingsboard.org'
TB_TENANT_PASSWORD_CE = 'tenant'

TB_SYSADMIN_USERNAME_CE = 'sysadmin@thingsboard.org'
TB_SYSADMIN_PASSWORD_CE = 'sysadmin'


class TBClientCETests(unittest.TestCase):
    client = None

    @classmethod
    def setUpClass(cls) -> None:
        # ThingsBoard REST API URL
        url = TB_URL_CE

        # Default Tenant Administrator credentials
        username = TB_TENANT_USERNAME_CE
        password = TB_TENANT_PASSWORD_CE

        with RestClientCE(url) as cls.client:
            cls.client.login(username, password)


class AlarmControllerTests(TBClientCETests):
    test_alarm = None
    device = None
    device_profile_id = None

    @classmethod
    def setUpClass(cls) -> None:
        super(AlarmControllerTests, cls).setUpClass()

        cls.device_profile_id = cls.client.get_default_device_profile_info().id

        cls.device = Device(name='Test', label='Test', device_profile_id=cls.device_profile_id)
        cls.device = cls.client.save_device(body=cls.device)

        cls.test_alarm = Alarm(name='Test', type='default',
                               originator=cls.device.id,
                               severity='CRITICAL', status='CLEARED_UNACK', acknowledged=False, cleared=False)
        cls.test_alarm = cls.client.save_alarm(cls.test_alarm)
        assert isinstance(cls.test_alarm, Alarm)

    @classmethod
    def tearDownClass(cls) -> None:
        cls.client.delete_alarm(cls.test_alarm.id)
        cls.client.delete_device(cls.device.id)

    def test_get_all_alarms(self):
        self.assertIsInstance(self.client.get_all_alarms(10, 0), PageDataAlarmInfo)

    def test_get_alarm_info_by_id(self):
        self.assertIsInstance(self.client.get_alarm_info_by_id(self.test_alarm.id), AlarmInfo)

    def test_get_alarms(self):
        self.assertIsInstance(self.client.get_alarms(self.device.id, 10, 0), PageDataAlarmInfo)

    def test_clear_alarm(self):
        self.assertIsInstance(self.client.clear_alarm(self.test_alarm.id), AlarmInfo)

    def test_ack_alarm(self):
        self.assertIsInstance(self.client.ack_alarm(self.test_alarm.id), AlarmInfo)

    def test_get_alarm_by_id(self):
        self.assertIsInstance(self.client.get_alarm_by_id(self.test_alarm.id), Alarm)


class AlarmCommentControllerTests(TBClientCETests):
    alarm = None
    alarm_comment = None
    device_profile_id = None
    device = None

    @classmethod
    def setUpClass(cls) -> None:
        super(AlarmCommentControllerTests, cls).setUpClass()

        cls.device_profile_id = cls.client.get_default_device_profile_info().id

        cls.device = Device(name='Test', label='Test', device_profile_id=cls.device_profile_id)
        cls.device = cls.client.save_device(body=cls.device)

        cls.test_alarm = cls.client.save_alarm(Alarm(name='Test', type='default',
                                                     originator=cls.device.id,
                                                     severity='CRITICAL', status='CLEARED_UNACK', acknowledged=False,
                                                     cleared=False))
        cls.alarm = cls.client.get_all_alarms(10, 0).data[0]
        cls.alarm_comment = cls.client.save_alarm_comment(cls.alarm.id,
                                                          AlarmComment(name='Test Comment', comment='Test comment'))

    def test_get_alarm_comments(self):
        self.assertIsInstance(self.client.get_alarm_comments(self.alarm.id, 10, 0), PageDataAlarmCommentInfo)

    @classmethod
    def tearDownClass(cls) -> None:
        cls.client.delete_alarm_comment(cls.alarm.id, cls.alarm_comment.id)
        cls.client.delete_alarm(cls.alarm.id)
        cls.client.delete_device(cls.device.id)


class AssetControllerTests(TBClientCETests):
    test_asset = None
    asset_profile_id = None

    @classmethod
    def setUpClass(cls) -> None:
        super(AssetControllerTests, cls).setUpClass()

        cls.asset_profile_id = cls.client.get_default_asset_profile_info().id
        cls.test_asset = Asset(name="Test Asset", asset_profile_id=cls.asset_profile_id)
        cls.test_asset = cls.client.save_asset(body=cls.test_asset)
        cls.customer = cls.client.get_customers(10, 0).data[0]

    @classmethod
    def tearDownClass(cls) -> None:
        cls.client.delete_asset(cls.test_asset.id)

    def test_get_tenant_assets(self):
        self.assertIsInstance(self.client.get_tenant_assets(10, 0), PageDataAsset)

    def test_get_tenant_asset(self):
        self.assertIsInstance(self.client.get_tenant_asset(self.test_asset.name), Asset)

    def test_get_tenant_asset_infos(self):
        self.assertIsInstance(self.client.get_tenant_asset_infos(10, 0), PageDataAssetInfo)

    def test_get_customer_assets(self):
        self.assertIsInstance(self.client.get_customer_assets(self.customer.id, 10, 0), PageDataAsset)

    def test_get_customer_asset_infos(self):
        self.assertIsInstance(self.client.get_customer_asset_infos(self.customer.id, 10, 0), PageDataAssetInfo)

    def test_get_assets_by_ids(self):
        self.assertIsInstance(self.client.get_assets_by_ids([self.test_asset.id.id]), list)

    def test_get_asset_types(self):
        self.assertIsInstance(self.client.get_asset_types(), list)

    def test_get_asset_info_by_id(self):
        self.assertIsInstance(self.client.get_asset_info_by_id(self.test_asset.id), AssetInfo)

    def test_get_asset_by_id(self):
        self.assertIsInstance(self.client.get_asset_by_id(self.test_asset.id), Asset)


class AssetProfileControllerTests(TBClientCETests):
    asset_profile = None

    @classmethod
    def setUpClass(cls) -> None:
        super(AssetProfileControllerTests, cls).setUpClass()

        cls.asset_profile = AssetProfile(name='Test Asset', default=False)
        cls.asset_profile = cls.client.save_asset_profile(cls.asset_profile)

    @classmethod
    def tearDownClass(cls) -> None:
        cls.client.delete_asset_profile(cls.asset_profile.id)

    def test_get_asset_profile_by_id(self):
        self.assertIsInstance(self.client.get_asset_profile_by_id(self.asset_profile.id), AssetProfile)

    def test_get_asset_profile_info_by_id(self):
        self.assertIsInstance(self.client.get_asset_profile_info_by_id(self.asset_profile.id), AssetProfileInfo)

    def test_get_default_asset_profile_info(self):
        self.assertIsInstance(self.client.get_default_asset_profile_info(), AssetProfileInfo)

    def test_get_asset_profile_infos(self):
        self.assertIsInstance(self.client.get_asset_profile_infos(10, 0), PageDataAssetProfileInfo)

    def test_get_asset_profiles(self):
        self.assertIsInstance(self.client.get_asset_profiles(10, 0), PageDataAssetProfile)


class AuditLogControllerTests(TBClientCETests):
    customer = None
    device = None

    @classmethod
    def setUpClass(cls) -> None:
        super(AuditLogControllerTests, cls).setUpClass()

        cls.customer = cls.client.get_customers(10, 0).data[0]

    def test_get_audit_logs(self):
        self.assertIsInstance(self.client.get_audit_logs(10, 0), PageDataAuditLog)

    def test_get_audit_logs_by_customer_id(self):
        self.assertIsInstance(self.client.get_audit_logs_by_customer_id(self.customer.id, 10, 0), PageDataAuditLog)

    def test_get_audit_logs_by_entity_id(self):
        self.assertIsInstance(self.client.get_audit_logs_by_entity_id(EntityId(self.customer.id, 'CUSTOMER'), 10, 0),
                              PageDataAuditLog)

    def test_get_audit_logs_by_user_id(self):
        self.assertIsInstance(self.client.get_audit_logs_by_user_id(UserId(self.customer.id, 'USER'), 10, 0),
                              PageDataAuditLog)


class TelemetryControllerTests(TBClientCETests):
    device = None
    device_profile_id = None

    @classmethod
    def setUpClass(cls) -> None:
        super(TelemetryControllerTests, cls).setUpClass()

        cls.device_profile_id = cls.client.get_default_device_profile_info().id
        cls.device = Device(name='Test CE', device_profile_id=cls.device_profile_id)
        cls.device = cls.client.save_device(cls.device)

    @classmethod
    def tearDownClass(cls) -> None:
        cls.client.delete_device(cls.device.id)

    def test_get_latest_timeseries(self):
        self.assertIsInstance(self.client.get_latest_timeseries(self.device.id), dict)

    def test_get_timeseries(self):
        self.assertIsInstance(self.client.get_timeseries(self.device.id, 'string_read3', 164999693900, 168999693900),
                              dict)

    def test_get_attributes_by_scope(self):
        self.assertIsInstance(self.client.get_attributes_by_scope(self.device.id, 'SHARED_SCOPE'), list)

    def test_get_attributes(self):
        self.assertIsInstance(self.client.get_attributes(self.device.id), list)

    def test_delete_entity_timeseries(self):
        self.assertIsInstance(
            self.client.delete_entity_timeseries(self.device.id,
                                                 'combination',
                                                 delete_all_data_for_keys=True), bytes)

    def test_save_entity_telemetry(self):
        self.assertEqual(
            self.client.save_entity_telemetry(self.device.id, 'ANY',
                                              body={"ts": 1634712287000,
                                                    "values": {"temperature": 26, "humidity": 87}}), b'')

    def test_save_entity_telemetry_with_ttl(self):
        self.assertEqual(
            self.client.save_entity_telemetry_with_ttl(self.device.id,
                                                       'ANY', body={"temperature": 26, "humidity": 87},
                                                       ttl=100), b'')

    def test_get_timeseries_keys(self):
        self.assertIsInstance(
            self.client.get_timeseries_keys(self.device_profile_id.id),
            list)

    def test_get_attribute_keys_by_scope(self):
        self.assertIsInstance(
            self.client.get_attribute_keys_by_scope(self.device.id,
                                                    'SHARED_SCOPE'), list)

    def test_get_attribute_keys(self):
        self.assertIsInstance(
            self.client.get_attribute_keys(self.device.id), list)

    def test_save_entity_attributes_v2(self):
        self.assertEqual(
            self.client.save_entity_attributes_v2(self.device.id,
                                                  'SHARED_SCOPE', {'shared1': 12}), b'')

    def test_delete_entity_attributes(self):
        self.assertEqual(
            self.client.delete_entity_attributes(self.device.id,
                                                 'SHARED_SCOPE', 'shared1'), b'')

    def test_save_entity_attributes_v1(self):
        self.assertEqual(
            self.client.save_entity_attributes_v1(self.device.id,
                                                  'SHARED_SCOPE', {'shared1': 12}), b'')

    def test_delete_device_attributes(self):
        self.assertEqual(
            self.client.delete_device_attributes(self.device.id,
                                                 'SHARED_SCOPE', 'shared1'), b'')

    def test_save_device_attributes(self):
        self.assertEqual(self.client.save_device_attributes(self.device.id,
                                                            'SHARED_SCOPE', {'shared1': 12}), b'')


class DeviceControllerTests(TBClientCETests):
    device = None
    device_profile_id = None
    customer = None

    @classmethod
    def setUpClass(cls) -> None:
        super(DeviceControllerTests, cls).setUpClass()

        cls.customer = cls.client.get_customers(10, 0).data[0]
        cls.device_profile_id = cls.device_profile_id = cls.client.get_default_device_profile_info().id
        cls.device = Device(name='Test', device_profile_id=cls.device_profile_id)
        cls.device = cls.client.save_device(cls.device)
        cls.cred = cls.client.get_device_credentials_by_device_id(cls.device.id)

    @classmethod
    def tearDownClass(cls) -> None:
        cls.client.delete_device(cls.device.id)

    def test_get_tenant_devices(self):
        self.assertIsInstance(self.client.get_tenant_devices(10, 0), PageDataDevice)
        sleep(1)

    def test_get_tenant_device(self):
        self.assertIsInstance(self.client.get_tenant_device(self.device.name), Device)

    def test_get_tenant_device_infos(self):
        self.assertIsInstance(self.client.get_tenant_device_infos(10, 0), PageDataDeviceInfo)

    def test_assign_device_to_tenant(self):
        tenant_id = self.client.get_user().tenant_id
        self.assertIsInstance(self.client.assign_device_to_tenant(tenant_id, self.device.id), Device)

    def test_count_by_device_profile_and_empty_ota_package(self):
        self.assertIsInstance(
            self.client.count_by_device_profile_and_empty_ota_package('FIRMWARE', self.device_profile_id.id), int)
        sleep(1)

    def test_get_devices_by_ids(self):
        self.assertIsInstance(
            self.client.get_devices_by_ids([self.device.id.id]), list)

    def test_get_device_types(self):
        self.assertIsInstance(self.client.get_device_types(), list)

    def test_get_device_credentials_by_device_id(self):
        self.assertIsInstance(self.client.get_device_credentials_by_device_id(self.device.id), DeviceCredentials)

    def test_update_device_credentials(self):
        self.assertIsInstance(self.client.update_device_credentials(
            DeviceCredentials(self.cred.id,
                              device_id=self.device.id,
                              credentials_id=self.cred.credentials_id, credentials_type='ACCESS_TOKEN',
                              credentials_value='fffadsfsdgsfddsfdddsdfsf')), DeviceCredentials)

    def test_get_device_by_id(self):
        self.assertIsInstance(self.client.get_device_by_id(self.device.id), Device)

    def test_re_claim_device(self):
        self.assertEqual(self.client.re_claim_device(self.device.name), b'')

    def test_get_customer_devices(self):
        self.assertIsInstance(self.client.get_customer_devices(self.customer.id, 10, 0), PageDataDevice)

    def test_save_device_with_credentials(self):
        test_device = Device(name='Test 1', type='default', device_profile_id=self.device_profile_id)
        test_device = self.client.save_device_with_credentials(
            SaveDeviceWithCredentialsRequest(test_device, DeviceCredentials(credentials_type='ACCESS_TOKEN',
                                                                            credentials_id='sdfsdfsdfsdfsdfsdf')))
        self.assertIsInstance(test_device, Device)
        self.client.delete_device(test_device.id)


class CustomerControllerTests(TBClientCETests):
    test_customer = None

    @classmethod
    def setUpClass(cls) -> None:
        super(CustomerControllerTests, cls).setUpClass()
        cls.test_customer = Customer(title='Test from test', name='Test')
        cls.test_customer = cls.client.save_customer(body=cls.test_customer)

    @classmethod
    def tearDownClass(cls) -> None:
        cls.client.delete_customer(cls.test_customer.id)

    def test_get_tenant_customer(self):
        self.assertIsInstance(self.client.get_tenant_customer(self.test_customer.title), Customer)

    def test_get_customers(self):
        self.assertIsInstance(self.client.get_customers(10, 0), PageDataCustomer)

    def test_get_customer_title_by_id(self):
        self.assertIsInstance(
            self.client.get_customer_title_by_id(self.test_customer.id), str)

    def test_get_short_customer_info_by_id(self):
        self.assertIsInstance(self.client.get_short_customer_info_by_id(self.test_customer.id), dict)

    def test_get_customer_by_id(self):
        self.assertIsInstance(self.client.get_customer_by_id(self.test_customer.id), Customer)


class DashboardControllerTests(TBClientCETests):
    test_dashboard = None
    customer = None

    @classmethod
    def setUpClass(cls) -> None:
        super(DashboardControllerTests, cls).setUpClass()

        cls.customer = cls.client.get_customers(10, 0).data[0]
        cls.test_dashboard = Dashboard(name='Test from test', title='Test from test')
        cls.client.save_dashboard(body=cls.test_dashboard)
        cls.test_dashboard = list(filter(lambda x: x.name == cls.test_dashboard.name,
                                         cls.client.get_tenant_dashboards(10, 0).data))[0]
        cls.client.set_tenant_home_dashboard_info(
            HomeDashboardInfo(cls.test_dashboard.id, hide_dashboard_toolbar=False))

    @classmethod
    def tearDownClass(cls) -> None:
        cls.client.delete_dashboard(cls.test_dashboard.id)

    def test_get_tenant_dashboards(self):
        self.assertIsInstance(self.client.get_tenant_dashboards(10, 0), PageDataDashboardInfo)

    def test_get_tenant_home_dashboard_info(self):
        self.assertIsInstance(self.client.get_tenant_home_dashboard_info(), HomeDashboardInfo)

    def test_set_tenant_home_dashboard_info(self):
        self.assertEqual(self.client.set_tenant_home_dashboard_info(
            HomeDashboardInfo(self.test_dashboard.id, hide_dashboard_toolbar=False)), None)

    def test_get_server_time(self):
        self.assertIsInstance(self.client.get_server_time(), int)

    def test_get_max_datapoints_limit(self):
        self.assertIsInstance(self.client.get_max_datapoints_limit(), int)

    def test_get_dashboard_info_by_id(self):
        self.assertIsInstance(
            self.client.get_dashboard_info_by_id(self.test_dashboard.id),
            DashboardInfo)

    def test_get_home_dashboard_info(self):
        self.assertIsInstance(self.client.get_home_dashboard_info(), HomeDashboardInfo)

    def test_get_home_dashboard(self):
        self.assertIsInstance(self.client.get_home_dashboard(), HomeDashboard)

    def test_get_dashboard_by_id(self):
        self.assertIsInstance(
            self.client.get_dashboard_by_id(self.test_dashboard.id), Dashboard)

    def test_get_customer_dashboards(self):
        self.assertIsInstance(self.client.get_customer_dashboards(self.customer.id, 10, 0), PageDataDashboardInfo)


class DeviceProfileControllerTests(TBClientCETests):
    test_device_profile = None

    @classmethod
    def setUpClass(cls) -> None:
        super(DeviceProfileControllerTests, cls).setUpClass()
        cls.test_device_profile = DeviceProfile(name='Test', type='DEFAULT', transport_type='MQTT',
                                                provision_type='ALLOW_CREATE_NEW_DEVICES',
                                                profile_data=DeviceProfileData(
                                                    configuration={"type": "DEFAULT"}, transport_configuration={
                                                        "type": "MQTT",
                                                        "deviceTelemetryTopic": "v1/devices/me/telemetry",
                                                        "deviceAttributesTopic": "v1/devices/me/attributes",
                                                        "transportPayloadTypeConfiguration": {
                                                            "transportPayloadType": "PROTOBUF",
                                                            "deviceTelemetryProtoSchema": "syntax =\"proto3\";\npackage telemetry;\n\nmessage SensorDataReading {\n\n  optional double temperature = 1;\n  optional double humidity = 2;\n  InnerObject innerObject = 3;\n\n  message InnerObject {\n    optional string key1 = 1;\n    optional bool key2 = 2;\n    optional double key3 = 3;\n    optional int32 key4 = 4;\n    optional string key5 = 5;\n  }\n}",
                                                            "deviceAttributesProtoSchema": "syntax =\"proto3\";\npackage attributes;\n\nmessage SensorConfiguration {\n  optional string firmwareVersion = 1;\n  optional string serialNumber = 2;\n}",
                                                            "deviceRpcRequestProtoSchema": "syntax =\"proto3\";\npackage rpc;\n\nmessage RpcRequestMsg {\n  optional string method = 1;\n  optional int32 requestId = 2;\n  optional string params = 3;\n}",
                                                            "deviceRpcResponseProtoSchema": "syntax =\"proto3\";\npackage rpc;\n\nmessage RpcResponseMsg {\n  optional string payload = 1;\n}"
                                                        }
                                                    }))
        cls.test_device_profile = cls.client.save_device_profile(cls.test_device_profile)

    @classmethod
    def tearDownClass(cls) -> None:
        cls.client.delete_device_profile(cls.test_device_profile.id)

    def test_get_device_profiles(self):
        self.assertIsInstance(self.client.get_device_profiles(10, 0), PageDataDeviceProfile)

    def test_get_device_profile_infos(self):
        self.assertIsInstance(self.client.get_device_profile_infos(10, 0), PageDataDeviceProfileInfo)

    def test_get_default_device_profile_info(self):
        self.assertIsInstance(self.client.get_default_device_profile_info(), DeviceProfileInfo)

    def test_get_device_profile_info_by_id(self):
        self.assertIsInstance(self.client.get_device_profile_info_by_id(self.test_device_profile.id), DeviceProfileInfo)

    def test_get_device_profile_by_id(self):
        self.assertIsInstance(self.client.get_device_profile_by_id(self.test_device_profile.id), DeviceProfile)


class EntityQueryControllerTests(TBClientCETests):
    user = None
    @classmethod
    def setUpClass(cls) -> None:
        super(EntityQueryControllerTests, cls).setUpClass()

        cls.user = cls.client.get_user()

    def test_count_alarms_by_query(self):
        self.assertIsInstance(self.client.count_alarms_by_query(AlarmCountQuery(assignee_id=self.user.id, key_filters=[
            KeyFilter(key={'key': 'temperature', 'type': 'TIME_SERIES'}, value_type='BOOLEAN')],
                                                                                search_propagated_alarms=True,
                                                                                severity_list=['CRITICAL'])), int)

    def test_find_alarms_by_query(self):
        alarm_query = AlarmDataQuery(alarm_fields=[{'key': 'createdTime', 'type': 'ALARM_FIELD'}],
                                     entity_fields=[{'key': 'name', 'type': 'ENTITY_FIELD'}],
                                     entity_filter=EntityFilter(type='entityType', resolve_multiple=True,
                                                                entity_type='DEVICE'), key_filters=[
                KeyFilter(key={'key': 'temperature', 'type': 'TIME_SERIES'}, value_type='BOOLEAN',
                          predicate={"operation": "GREATER",
                                     "value": {
                                         "defaultValue": 0,
                                         "dynamicValue": None
                                     },
                                     "type": "NUMERIC"})],
                                     latest_values=[{'key': 'model', 'type': 'ATTRIBUTE'}],
                                     page_link=AlarmDataPageLink(dynamic=True,
                                                                 search_propagated_alarms=True,
                                                                 severity_list=[
                                                                     'CRITICAL'], page_size=10))
        self.assertIsInstance(self.client.find_alarm_data_by_query(alarm_query), PageDataAlarmData)

    def test_count_entities_by_query(self):
        entity_count_query = EntityCountQuery(entity_filter=EntityFilter(type='entityType', entity_type='DEVICE'),
                                              key_filters=[KeyFilter(key={"type": "ATTRIBUTE",
                                                                          "key": "active"}, value_type='BOOLEAN',
                                                                     predicate={"operation": "EQUAL",
                                                                                "value": {
                                                                                    "defaultValue": True,
                                                                                    "dynamicValue": None
                                                                                },
                                                                                "type": "BOOLEAN"})])
        self.assertIsInstance(self.client.count_entities_by_query(entity_count_query), int)

    def test_find_entity_data_by_query(self):
        entity_data_query = EntityDataQuery(
            entity_filter=EntityFilter(type='entityType', resolve_multiple=True, entity_type='DEVICE'),
            key_filters=[KeyFilter(key={"type": "TIME_SERIES",
                                        "key": "temperature"},
                                   value_type='NUMERIC',
                                   predicate={"operation": "GREATER",
                                              "value": {
                                                  "defaultValue": 0,
                                                  "dynamicValue": {
                                                      "sourceType": "CURRENT_USER",
                                                      "sourceAttribute": "temperatureThreshold",
                                                      "inherit": False
                                                  }
                                              },
                                              "type": "NUMERIC"})],
            entity_fields=[{"type": "ENTITY_FIELD",
                            "key": "name"}],
            latest_values=[{
                "type": "ATTRIBUTE",
                "key": "model"
            }],
            page_link={"page": 0,
                       "pageSize": 10,
                       "sortOrder": {
                           "key": {
                               "key": "name",
                               "type": "ENTITY_FIELD"
                           },
                           "direction": "ASC"
                       }})
        self.assertIsInstance(self.client.find_entity_data_by_query(entity_data_query), PageDataEntityData)

    def test_find_entity_keys_by_query(self):
        entity_data_query = EntityDataQuery(
            entity_filter=EntityFilter(type='entityType', resolve_multiple=True, entity_type='DEVICE'),
            key_filters=[KeyFilter(key={"type": "TIME_SERIES",
                                        "key": "temperature"},
                                   value_type='NUMERIC',
                                   predicate={"operation": "GREATER",
                                              "value": {
                                                  "defaultValue": 0,
                                                  "dynamicValue": {
                                                      "sourceType": "CURRENT_USER",
                                                      "sourceAttribute": "temperatureThreshold",
                                                      "inherit": False
                                                  }
                                              },
                                              "type": "NUMERIC"})],
            entity_fields=[{"type": "ENTITY_FIELD",
                            "key": "name"}],
            latest_values=[{
                "type": "ATTRIBUTE",
                "key": "model"
            }],
            page_link={"page": 0,
                       "pageSize": 10,
                       "sortOrder": {
                           "key": {
                               "key": "name",
                               "type": "ENTITY_FIELD"
                           },
                           "direction": "ASC"
                       }})
        self.assertIsInstance(
            self.client.find_entity_timeseries_and_attributes_keys_by_query(timeseries=True, attributes=True,
                                                                            body=entity_data_query), dict)


class EntityRelationControllerTests(TBClientCETests):
    test_relation = None
    test_asset = None
    test_device = None
    device_profile_id = None
    asset_device_profile_id = None

    @classmethod
    def setUpClass(cls) -> None:
        super(EntityRelationControllerTests, cls).setUpClass()

        cls.device_profile_id = cls.client.get_default_device_profile_info().id

        cls.test_device = Device(name='Test from test 1', device_profile_id=cls.device_profile_id)
        cls.test_device = cls.client.save_device(cls.test_device)

        cls.asset_device_profile_id = cls.client.get_default_asset_profile_info().id
        cls.test_asset = Asset(name="Test Asset", asset_profile_id=cls.asset_device_profile_id)
        cls.test_asset = cls.client.save_asset(body=cls.test_asset)

        cls.test_relation = EntityRelation(_from=cls.test_asset.id, to=cls.test_device.id, type="Contains")
        cls.client.save_relation(cls.test_relation)

    @classmethod
    def tearDownClass(cls) -> None:
        cls.client.delete_relation(from_id=cls.test_asset.id, to_id=cls.test_device.id, relation_type='Contains')
        cls.client.delete_asset(cls.test_asset.id)
        cls.client.delete_device(cls.test_device.id)

    def test_find_info_by_to(self):
        self.assertIsInstance(self.client.find_info_by_to(self.test_device.id, 'DEVICE'), list)

    def test_find_info_by_from(self):
        self.assertIsInstance(self.client.find_info_by_from(self.test_asset.id), list)

    def test_find_by_to(self):
        self.assertIsInstance(self.client.find_by_to(self.test_device.id, 'Contains'), list)

    def test_find_by_from(self):
        self.assertIsInstance(self.client.find_by_from(self.test_asset.id, 'Contains'), list)

    def test_get_relation(self):
        self.assertIsInstance(self.client.get_relation(self.test_asset.id, 'Contains', self.test_device.id),
                              EntityRelation)


class EntityViewControllerTests(TBClientCETests):
    test_entity_view = None
    device = None
    device_profile_id = None
    customer = None

    @classmethod
    def setUpClass(cls) -> None:
        super(EntityViewControllerTests, cls).setUpClass()

        cls.customer = cls.client.get_customers(10, 0).data[0]

        cls.device_profile_id = cls.client.get_default_device_profile_info().id

        cls.device = Device(name='Test', device_profile_id=cls.device_profile_id)
        cls.device = cls.client.save_device(cls.device)

        cls.test_entity_view = EntityView(name='Test', type='default',
                                          entity_id=cls.device.id,
                                          keys=TelemetryEntityView(timeseries=['temp'],
                                                                   attributes=AttributesEntityView(cs=['fff'],
                                                                                                   sh=['shared'],
                                                                                                   ss=['active'])))
        cls.test_entity_view = cls.client.save_entity_view(cls.test_entity_view)

    @classmethod
    def tearDownClass(cls) -> None:
        cls.client.delete_entity_view(cls.test_entity_view.id)
        cls.client.delete_device(cls.device.id)

    def test_get_tenant_entity_views(self):
        self.assertIsInstance(self.client.get_tenant_entity_views(10, 0), PageDataEntityView)

    def test_get_tenant_entity_view(self):
        self.assertIsInstance(self.client.get_tenant_entity_view(self.test_entity_view.name), EntityView)

    def test_get_entity_view_types(self):
        self.assertIsInstance(self.client.get_entity_view_types(), list)

    def test_get_entity_view_by_id(self):
        self.assertIsInstance(self.client.get_entity_view_by_id(self.test_entity_view.id), EntityView)

    def test_get_customer_entity_views(self):
        self.assertIsInstance(self.client.get_customer_entity_views(self.customer.id, 10, 0), PageDataEntityView)


class UserControllerTests(TBClientCETests):
    test_user = None
    customer = None

    @classmethod
    def setUpClass(cls) -> None:
        super(UserControllerTests, cls).setUpClass()

        cls.customer = cls.client.get_customers(10, 0).data[0]
        cls.test_user = User(name='Test User', email='admin11@gmail.com', authority='TENANT_ADMIN')
        cls.test_user = cls.client.save_user(cls.test_user, send_activation_mail=False)

    @classmethod
    def tearDownClass(cls) -> None:
        cls.client.delete_user(cls.test_user.id)

    def test_get_users(self):
        self.assertIsInstance(self.client.get_users(10, 0), PageDataUser)

    def test_is_user_token_access_enabled(self):
        self.assertIsInstance(self.client.is_user_token_access_enabled(), bool)

    def test_get_user_token(self):
        self.assertIsInstance(self.client.get_user_token(self.test_user.id), JWTPair)

    def test_get_activation_link(self):
        self.assertIsInstance(self.client.get_activation_link(self.test_user.id), str)

    def test_get_user_by_id(self):
        self.assertIsInstance(self.client.get_user_by_id(self.test_user.id), User)

    def test_get_customer_users(self):
        self.assertIsInstance(self.client.get_customer_users(self.customer.id, 10, 0), PageDataUser)


class NotificationControllerTests(TBClientCETests):
    notification = None
    template = None
    notification_target = None

    @classmethod
    def setUpClass(cls) -> None:
        super(NotificationControllerTests, cls).setUpClass()

        cls.notification_target = NotificationTarget(name='Test CE',
                                                     configuration=NotificationTargetConfig(type='PLATFORM_USERS',
                                                                                            description='test',
                                                                                            users_filter={
                                                                                                'type': 'ALL_USERS'}))
        cls.notification_target = cls.client.save_notification_target(cls.notification_target)

        cls.template = cls.client.get_notification_templates(10, 0).data[0]

        cls.notification = NotificationRequest(additional_config=NotificationRequestConfig(sending_delay_in_sec=0),
                                               targets=[cls.notification_target.id.id], template_id=cls.template.id,
                                               status='PROCESSING')
        cls.notification = cls.client.create_notification_request(cls.notification)

    def test_get_available_delivery_methods(self):
        self.assertIsInstance(self.client.get_available_delivery_methods(), list)

    def test_get_notification_request_by_id(self):
        self.assertIsInstance(self.client.get_notification_request_by_id(self.notification.id), NotificationRequestInfo)

    def test_get_notification_requests(self):
        self.assertIsInstance(self.client.get_notification_requests(10, 0), PageDataNotificationRequestInfo)

    def test_get_notification_settings(self):
        self.assertIsInstance(self.client.get_notification_settings(), NotificationSettings)

    def test_get_notifications(self):
        self.assertIsInstance(self.client.get_notifications(10, 0), PageDataNotification)

    @classmethod
    def tearDownClass(cls) -> None:
        cls.client.delete_notification(cls.notification.id)
        cls.client.delete_notification_target_by_id(cls.notification_target.id)


class NotificationTemplateControllerTests(TBClientCETests):
    template = None

    @classmethod
    def setUpClass(cls) -> None:
        super(NotificationTemplateControllerTests, cls).setUpClass()

        cls.template = NotificationTemplate(name='Hello to all my users', configuration=NotificationTemplateConfig(
            delivery_methods_templates={
                'WEB': {'method': 'WEB', 'subject': 'Hello', 'body': 'Hello', 'enabled': True}}),
                                            notification_type='GENERAL')
        cls.template = cls.client.save_notification_template(cls.template)

    def test_get_notification_template_by_id(self):
        self.assertIsInstance(self.client.get_notification_template_by_id(self.template.id), NotificationTemplate)

    def test_get_notification_templates(self):
        self.assertIsInstance(self.client.get_notification_templates(10, 0), PageDataNotificationTemplate)

    @classmethod
    def tearDownClass(cls) -> None:
        cls.client.delete_notification_template_by_id(cls.template.id)


class NotificationTargetControllerTests(TBClientCETests):
    notification_target = None

    @classmethod
    def setUpClass(cls) -> None:
        super(NotificationTargetControllerTests, cls).setUpClass()

        cls.notification_target = NotificationTarget(name='Test CE',
                                                     configuration=NotificationTargetConfig(type='PLATFORM_USERS',
                                                                                            description='test',
                                                                                            users_filter={
                                                                                                'type': 'ALL_USERS'}))
        cls.notification_target = cls.client.save_notification_target(cls.notification_target)

    @classmethod
    def tearDownClass(cls) -> None:
        cls.client.delete_notification_target_by_id(cls.notification_target.id)

    def test_get_notification_target_by_id(self):
        self.assertIsInstance(self.client.get_notification_target_by_id(self.notification_target.id),
                              NotificationTarget)

    def test_get_notification_targets_by_ids(self):
        self.assertIsInstance(self.client.get_notification_targets_by_ids([self.notification_target.id.id]), list)

    def test_get_notification_targets_by_supported_notification_type(self):
        self.assertIsInstance(self.client.get_notification_targets_by_supported_notification_type('ALARM', 10, 0),
                              PageDataNotificationTarget)

    def test_get_notification_targets(self):
        self.assertIsInstance(self.client.get_notification_targets(10, 0), PageDataNotificationTarget)


class NotificationRuleControllerTests(TBClientCETests):
    rule = None
    template = None

    @classmethod
    def setUpClass(cls) -> None:
        super(NotificationRuleControllerTests, cls).setUpClass()

        cls.template = NotificationTemplate(name='Hello to all my users', configuration=NotificationTemplateConfig(
            delivery_methods_templates={
                'WEB': {'method': 'WEB', 'subject': 'Hello', 'body': 'Hello', 'enabled': True}}),
                                            notification_type='GENERAL')
        cls.template = cls.client.save_notification_template(cls.template)

        cls.rule = NotificationRule(name='Test', trigger_type='ALARM',
                                    recipients_config={'triggerType': 'ALARM', 'escalationTable': {'0': []}},
                                    trigger_config=NotificationRuleTriggerConfig(trigger_type='ALARM', notify_on=['CREATED']),
                                    template_id=cls.template.id)
        cls.rule = cls.client.save_notification_rule(cls.rule)
        print(cls.rule)

    @classmethod
    def tearDownClass(cls) -> None:
        cls.client.delete_notification_rule(cls.rule.id)
        cls.client.delete_notification_template_by_id(cls.template.id)

    def test_get_notification_rule_by_id(self):
        self.assertIsInstance(self.client.get_notification_rule_by_id(self.rule.id), NotificationRuleInfo)

    def test_get_notification_rules(self):
        self.assertIsInstance(self.client.get_notification_rules(10, 0), PageDataNotificationRuleInfo)


class TenantControllerTests(TBClientCETests):
    tenant = None
    tenant_profile_id = None

    @classmethod
    def setUpClass(cls) -> None:
        # ThingsBoard REST API URL
        url = TB_URL_CE

        # Default Tenant Administrator credentials
        username = TB_SYSADMIN_USERNAME_CE
        password = TB_SYSADMIN_PASSWORD_CE

        with RestClientCE(url) as cls.client:
            cls.client.login(username, password)

        cls.tenant_profile_id = cls.client.get_default_tenant_profile_info().id
        cls.tenant = Tenant(tenant_profile_id=cls.tenant_profile_id, email='test@test.org', title='Test')
        cls.tenant = cls.client.save_tenant(cls.tenant)

    @classmethod
    def tearDownClass(cls) -> None:
        cls.client.delete_tenant(cls.tenant.id)

    def test_get_tenant_by_id(self):
        self.assertIsInstance(self.client.get_tenant_by_id(self.tenant.id), Tenant)

    def test_get_tenant_info_by_id(self):
        self.assertIsInstance(self.client.get_tenant_info_by_id(self.tenant.id), TenantInfo)

    def test_get_tenants(self):
        self.assertIsInstance(self.client.get_tenants(10, 0), PageDataTenant)


class TenantProfileControllerTests(TBClientCETests):
    tenant_profile = None

    @classmethod
    def setUpClass(cls) -> None:
        # ThingsBoard REST API URL
        url = TB_URL_CE

        # Default Tenant Administrator credentials
        username = TB_SYSADMIN_USERNAME_CE
        password = TB_SYSADMIN_PASSWORD_CE

        with RestClientCE(url) as cls.client:
            cls.client.login(username, password)

        cls.tenant_profile = TenantProfile(default=False, isolated_tb_rule_engine=False, name='Test')
        cls.tenant_profile = cls.client.save_tenant_profile(cls.tenant_profile)

    @classmethod
    def tearDownClass(cls) -> None:
        cls.client.delete_tenant_profile(cls.tenant_profile.id)

    def test_get_tenant_profile_by_id(self):
        self.assertIsInstance(self.client.get_tenant_profile_by_id(self.tenant_profile.id), TenantProfile)

    def test_get_tenant_profile_info_by_id(self):
        self.assertIsInstance(self.client.get_tenant_profile_info_by_id(self.tenant_profile.id), EntityInfo)

    def test_get_default_tenant_profile_info(self):
        self.assertIsInstance(self.client.get_default_tenant_profile_info(), EntityInfo)

    def test_get_tenant_profile_infos(self):
        self.assertIsInstance(self.client.get_tenant_profile_infos(10, 0), PageDataEntityInfo)

    def test_get_tenant_profiles_by_ids(self):
        self.assertIsInstance(self.client.get_tenant_profiles_by_ids([self.tenant_profile.id.id]), list)

    def test_get_tenant_profiles(self):
        self.assertIsInstance(self.client.get_tenant_profiles(10, 0), PageDataTenantProfile)


class UiSettingsControllerTests(TBClientCETests):
    def test_get_help_base_url(self):
        self.assertIsInstance(self.client.get_help_base_url(), str)


class UsageInfoControllerTests(TBClientCETests):
    def test_get_tenant_usage_info(self):
        self.assertIsInstance(self.client.get_tenant_usage_info(), UsageInfo)


class WidgetBundleControllerTests(TBClientCETests):
    widget_bundle = None

    @classmethod
    def setUpClass(cls) -> None:
        super(WidgetBundleControllerTests, cls).setUpClass()

        cls.widget_bundle = WidgetsBundle(name='Test', alias='test', title='Test')
        cls.widget_bundle = cls.client.save_widgets_bundle(cls.widget_bundle)

    @classmethod
    def tearDownClass(cls) -> None:
        cls.client.delete_widgets_bundle(cls.widget_bundle.id)

    def test_get_widgets_bundle_by_id(self):
        self.assertIsInstance(self.client.get_widgets_bundle_by_id(self.widget_bundle.id), WidgetsBundle)

    def test_get_all_widgets_bundles(self):
        self.assertIsInstance(self.client.get_widgets_bundles(), list)

    def test_get_widget_bundles(self):
        self.assertIsInstance(self.client.get_widgets_bundles_v1(10, 0), PageDataWidgetsBundle)


class WidgetTypeControllerTests(TBClientCETests):
    widget_bundle = None
    widget_type = None

    @classmethod
    def setUpClass(cls) -> None:
        super(WidgetTypeControllerTests, cls).setUpClass()

        cls.widget_bundle = WidgetsBundle(name='Test', alias='test', title='Test')
        cls.widget_bundle = cls.client.save_widgets_bundle(cls.widget_bundle)

        cls.widget_type = WidgetType(descriptor={'controllerScript': '', 'dataKeySettingsSchema': {}, 'defaultConfig': {}}, name='Test')
        cls.widget_type = cls.client.save_widget_type(cls.widget_type)

    @classmethod
    def tearDownClass(cls) -> None:
        cls.client.delete_widget_type(cls.widget_type.id)

    def test_get_widget_type_by_id(self):
        self.assertIsInstance(self.client.get_widget_type_by_id(self.widget_type.id), WidgetTypeDetails)

    def test_get_widget_type(self):
        self.assertIsInstance(self.client.get_widget_type(self.widget_type.fqn), WidgetType)

    def test_get_bundle_widget_types(self):
        self.assertIsInstance(self.client.get_bundle_widget_types(self.widget_bundle.id), list)

    def test_get_bundle_widget_types_infos(self):
        self.assertIsInstance(self.client.get_bundle_widget_types_infos(self.widget_bundle.id, 10, 0),
                              PageDataWidgetTypeInfo)


class DeviceConnectivityControllerTests(TBClientCETests):
    device_profile_id = None
    device = None

    @classmethod
    def setUpClass(cls) -> None:
        super(DeviceConnectivityControllerTests, cls).setUpClass()

        cls.device_profile_id = cls.client.get_default_device_profile_info().id

        cls.device = Device(name='Test', label='Test', device_profile_id=cls.device_profile_id)
        cls.device = cls.client.save_device(body=cls.device)

    @classmethod
    def tearDownClass(cls) -> None:
        cls.client.delete_device(cls.device.id)

    def test_get_device_publish_telemetry_commands(self):
        self.assertIsInstance(self.client.get_device_publish_telemetry_commands(self.device.id), dict)

class AdminControllerTests(TBClientCETests):
    @classmethod
    def setUpClass(cls) -> None:
        # ThingsBoard REST API URL
        url = TB_URL_CE

        # Default Tenant Administrator credentials
        username = TB_SYSADMIN_USERNAME_CE
        password = TB_SYSADMIN_PASSWORD_CE

        with RestClientCE(url) as cls.client:
            cls.client.login(username, password)

    def test_get_authorization_url(self):
        self.assertIsInstance(self.client.get_authorization_url(), str)

    def test_get_mail_processing_url(self):
        self.assertIsInstance(self.client.get_mail_processing_url(), str)


class ImageControllerTests(TBClientCETests):
    image_info = None

    @classmethod
    def setUpClass(cls) -> None:
        super(ImageControllerTests, cls).setUpClass()

        cls.image_info = cls.client.upload_image('test', 'data/images/task_done.png')

    @classmethod
    def tearDownClass(cls) -> None:
        cls.client.delete_image('tenant', 'task_done.png')

    def test_upload_image(self):
        self.assertIsInstance(self.client.upload_image('tenant', 'data/images/task_done.png'), TbResourceInfo)

    def test_update_image(self):
        self.assertIsInstance(self.client.update_image('tenant', 'task_done.png', 'data/images/task_done.png'),
                              TbResourceInfo)

    def test_get_image_info(self):
        self.assertIsInstance(self.client.get_image_info('tenant', 'task_done.png'), TbResourceInfo)

    def test_get_images(self):
        self.assertIsInstance(self.client.get_images(10, 0), PageDataTbResourceInfo)

    def test_download_image(self):
        self.assertIsInstance(self.client.download_image('tenant', 'task_done.png'), str)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    ThingsBoard REST API

     ThingsBoard open-source IoT platform REST API documentation.  # noqa: E501

    OpenAPI spec version: 3.6.2
    Contact: info@thingsboard.io
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

#  Copyright 2024. ThingsBoard
#
#  Licensed under the Apache License, Version 2.0 (the "License");
#  you may not use this file except in compliance with the License.
#  You may obtain a copy of the License at
#
#   http://www.apache.org/licenses/LICENSE-2.0
#
#  Unless required by applicable law or agreed to in writing, software
#  distributed under the License is distributed on an "AS IS" BASIS,
#  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
#  See the License for the specific language governing permissions and
#  limitations under the License.

import pprint
import re  # noqa: F401

import six

class AssetProfile(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'id': 'AssetProfileId',
        'created_time': 'int',
        'tenant_id': 'TenantId',
        'name': 'str',
        'default': 'bool',
        'default_dashboard_id': 'DashboardId',
        'default_rule_chain_id': 'RuleChainId',
        'default_queue_name': 'str',
        'description': 'str',
        'image': 'str',
        'default_edge_rule_chain_id': 'RuleChainId'
    }

    attribute_map = {
        'id': 'id',
        'created_time': 'createdTime',
        'tenant_id': 'tenantId',
        'name': 'name',
        'default': 'default',
        'default_dashboard_id': 'defaultDashboardId',
        'default_rule_chain_id': 'defaultRuleChainId',
        'default_queue_name': 'defaultQueueName',
        'description': 'description',
        'image': 'image',
        'default_edge_rule_chain_id': 'defaultEdgeRuleChainId'
    }

    def __init__(self, id=None, created_time=None, tenant_id=None, name=None, default=None, default_dashboard_id=None, default_rule_chain_id=None, default_queue_name=None, description=None, image=None, default_edge_rule_chain_id=None):  # noqa: E501
        """AssetProfile - a model defined in Swagger"""  # noqa: E501
        self._id = None
        self._created_time = None
        self._tenant_id = None
        self._name = None
        self._default = None
        self._default_dashboard_id = None
        self._default_rule_chain_id = None
        self._default_queue_name = None
        self._description = None
        self._image = None
        self._default_edge_rule_chain_id = None
        self.discriminator = None
        if id is not None:
            self.id = id
        if created_time is not None:
            self.created_time = created_time
        if tenant_id is not None:
            self.tenant_id = tenant_id
        if name is not None:
            self.name = name
        if default is not None:
            self.default = default
        if default_dashboard_id is not None:
            self.default_dashboard_id = default_dashboard_id
        if default_rule_chain_id is not None:
            self.default_rule_chain_id = default_rule_chain_id
        if default_queue_name is not None:
            self.default_queue_name = default_queue_name
        if description is not None:
            self.description = description
        if image is not None:
            self.image = image
        if default_edge_rule_chain_id is not None:
            self.default_edge_rule_chain_id = default_edge_rule_chain_id

    @property
    def id(self):
        """Gets the id of this AssetProfile.  # noqa: E501


        :return: The id of this AssetProfile.  # noqa: E501
        :rtype: AssetProfileId
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this AssetProfile.


        :param id: The id of this AssetProfile.  # noqa: E501
        :type: AssetProfileId
        """

        self._id = id

    @property
    def created_time(self):
        """Gets the created_time of this AssetProfile.  # noqa: E501

        Timestamp of the profile creation, in milliseconds  # noqa: E501

        :return: The created_time of this AssetProfile.  # noqa: E501
        :rtype: int
        """
        return self._created_time

    @created_time.setter
    def created_time(self, created_time):
        """Sets the created_time of this AssetProfile.

        Timestamp of the profile creation, in milliseconds  # noqa: E501

        :param created_time: The created_time of this AssetProfile.  # noqa: E501
        :type: int
        """

        self._created_time = created_time

    @property
    def tenant_id(self):
        """Gets the tenant_id of this AssetProfile.  # noqa: E501


        :return: The tenant_id of this AssetProfile.  # noqa: E501
        :rtype: TenantId
        """
        return self._tenant_id

    @tenant_id.setter
    def tenant_id(self, tenant_id):
        """Sets the tenant_id of this AssetProfile.


        :param tenant_id: The tenant_id of this AssetProfile.  # noqa: E501
        :type: TenantId
        """

        self._tenant_id = tenant_id

    @property
    def name(self):
        """Gets the name of this AssetProfile.  # noqa: E501

        Unique Asset Profile Name in scope of Tenant.  # noqa: E501

        :return: The name of this AssetProfile.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this AssetProfile.

        Unique Asset Profile Name in scope of Tenant.  # noqa: E501

        :param name: The name of this AssetProfile.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def default(self):
        """Gets the default of this AssetProfile.  # noqa: E501

        Used to mark the default profile. Default profile is used when the asset profile is not specified during asset creation.  # noqa: E501

        :return: The default of this AssetProfile.  # noqa: E501
        :rtype: bool
        """
        return self._default

    @default.setter
    def default(self, default):
        """Sets the default of this AssetProfile.

        Used to mark the default profile. Default profile is used when the asset profile is not specified during asset creation.  # noqa: E501

        :param default: The default of this AssetProfile.  # noqa: E501
        :type: bool
        """

        self._default = default

    @property
    def default_dashboard_id(self):
        """Gets the default_dashboard_id of this AssetProfile.  # noqa: E501


        :return: The default_dashboard_id of this AssetProfile.  # noqa: E501
        :rtype: DashboardId
        """
        return self._default_dashboard_id

    @default_dashboard_id.setter
    def default_dashboard_id(self, default_dashboard_id):
        """Sets the default_dashboard_id of this AssetProfile.


        :param default_dashboard_id: The default_dashboard_id of this AssetProfile.  # noqa: E501
        :type: DashboardId
        """

        self._default_dashboard_id = default_dashboard_id

    @property
    def default_rule_chain_id(self):
        """Gets the default_rule_chain_id of this AssetProfile.  # noqa: E501


        :return: The default_rule_chain_id of this AssetProfile.  # noqa: E501
        :rtype: RuleChainId
        """
        return self._default_rule_chain_id

    @default_rule_chain_id.setter
    def default_rule_chain_id(self, default_rule_chain_id):
        """Sets the default_rule_chain_id of this AssetProfile.


        :param default_rule_chain_id: The default_rule_chain_id of this AssetProfile.  # noqa: E501
        :type: RuleChainId
        """

        self._default_rule_chain_id = default_rule_chain_id

    @property
    def default_queue_name(self):
        """Gets the default_queue_name of this AssetProfile.  # noqa: E501

        Rule engine queue name. If present, the specified queue will be used to store all unprocessed messages related to asset, including asset updates, telemetry, attribute updates, etc. Otherwise, the 'Main' queue will be used to store those messages.  # noqa: E501

        :return: The default_queue_name of this AssetProfile.  # noqa: E501
        :rtype: str
        """
        return self._default_queue_name

    @default_queue_name.setter
    def default_queue_name(self, default_queue_name):
        """Sets the default_queue_name of this AssetProfile.

        Rule engine queue name. If present, the specified queue will be used to store all unprocessed messages related to asset, including asset updates, telemetry, attribute updates, etc. Otherwise, the 'Main' queue will be used to store those messages.  # noqa: E501

        :param default_queue_name: The default_queue_name of this AssetProfile.  # noqa: E501
        :type: str
        """

        self._default_queue_name = default_queue_name

    @property
    def description(self):
        """Gets the description of this AssetProfile.  # noqa: E501

        Asset Profile description.   # noqa: E501

        :return: The description of this AssetProfile.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this AssetProfile.

        Asset Profile description.   # noqa: E501

        :param description: The description of this AssetProfile.  # noqa: E501
        :type: str
        """

        self._description = description

    @property
    def image(self):
        """Gets the image of this AssetProfile.  # noqa: E501

        Either URL or Base64 data of the icon. Used in the mobile application to visualize set of asset profiles in the grid view.   # noqa: E501

        :return: The image of this AssetProfile.  # noqa: E501
        :rtype: str
        """
        return self._image

    @image.setter
    def image(self, image):
        """Sets the image of this AssetProfile.

        Either URL or Base64 data of the icon. Used in the mobile application to visualize set of asset profiles in the grid view.   # noqa: E501

        :param image: The image of this AssetProfile.  # noqa: E501
        :type: str
        """

        self._image = image

    @property
    def default_edge_rule_chain_id(self):
        """Gets the default_edge_rule_chain_id of this AssetProfile.  # noqa: E501


        :return: The default_edge_rule_chain_id of this AssetProfile.  # noqa: E501
        :rtype: RuleChainId
        """
        return self._default_edge_rule_chain_id

    @default_edge_rule_chain_id.setter
    def default_edge_rule_chain_id(self, default_edge_rule_chain_id):
        """Sets the default_edge_rule_chain_id of this AssetProfile.


        :param default_edge_rule_chain_id: The default_edge_rule_chain_id of this AssetProfile.  # noqa: E501
        :type: RuleChainId
        """

        self._default_edge_rule_chain_id = default_edge_rule_chain_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(AssetProfile, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AssetProfile):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    ThingsBoard REST API

     ThingsBoard Professional Edition IoT platform REST API documentation.  # noqa: E501

    OpenAPI spec version: 3.3.3PAAS-RC1
    Contact: info@thingsboard.io
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

#  Copyright 2024. ThingsBoard
#
#  Licensed under the Apache License, Version 2.0 (the "License");
#  you may not use this file except in compliance with the License.
#  You may obtain a copy of the License at
#
#   http://www.apache.org/licenses/LICENSE-2.0
#
#  Unless required by applicable law or agreed to in writing, software
#  distributed under the License is distributed on an "AS IS" BASIS,
#  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
#  See the License for the specific language governing permissions and
#  limitations under the License.

import pprint
import re  # noqa: F401

import six

class SubscriptionUsage(object):
    """NOTE: This class is auto generated by the swagger code generator program.
from tb_rest_client.api_client import ApiClient
    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'alarms': 'int',
        'assets': 'int',
        'converters': 'int',
        'customers': 'int',
        'dashboards': 'int',
        'devices': 'int',
        'dp_storage_days': 'int',
        'emails': 'int',
        'integrations': 'int',
        'js_executions': 'int',
        're_executions': 'int',
        'rule_chains': 'int',
        'scheduler_events': 'int',
        'sms': 'int',
        'transport_data_points': 'int',
        'transport_messages': 'int',
        'users': 'int'
    }

    attribute_map = {
        'alarms': 'alarms',
        'assets': 'assets',
        'converters': 'converters',
        'customers': 'customers',
        'dashboards': 'dashboards',
        'devices': 'devices',
        'dp_storage_days': 'dpStorageDays',
        'emails': 'emails',
        'integrations': 'integrations',
        'js_executions': 'jsExecutions',
        're_executions': 'reExecutions',
        'rule_chains': 'ruleChains',
        'scheduler_events': 'schedulerEvents',
        'sms': 'sms',
        'transport_data_points': 'transportDataPoints',
        'transport_messages': 'transportMessages',
        'users': 'users'
    }

    def __init__(self, alarms=None, assets=None, converters=None, customers=None, dashboards=None, devices=None, dp_storage_days=None, emails=None, integrations=None, js_executions=None, re_executions=None, rule_chains=None, scheduler_events=None, sms=None, transport_data_points=None, transport_messages=None, users=None):  # noqa: E501
        """SubscriptionUsage - a model defined in Swagger"""  # noqa: E501
        self._alarms = None
        self._assets = None
        self._converters = None
        self._customers = None
        self._dashboards = None
        self._devices = None
        self._dp_storage_days = None
        self._emails = None
        self._integrations = None
        self._js_executions = None
        self._re_executions = None
        self._rule_chains = None
        self._scheduler_events = None
        self._sms = None
        self._transport_data_points = None
        self._transport_messages = None
        self._users = None
        self.discriminator = None
        if alarms is not None:
            self.alarms = alarms
        if assets is not None:
            self.assets = assets
        if converters is not None:
            self.converters = converters
        if customers is not None:
            self.customers = customers
        if dashboards is not None:
            self.dashboards = dashboards
        if devices is not None:
            self.devices = devices
        if dp_storage_days is not None:
            self.dp_storage_days = dp_storage_days
        if emails is not None:
            self.emails = emails
        if integrations is not None:
            self.integrations = integrations
        if js_executions is not None:
            self.js_executions = js_executions
        if re_executions is not None:
            self.re_executions = re_executions
        if rule_chains is not None:
            self.rule_chains = rule_chains
        if scheduler_events is not None:
            self.scheduler_events = scheduler_events
        if sms is not None:
            self.sms = sms
        if transport_data_points is not None:
            self.transport_data_points = transport_data_points
        if transport_messages is not None:
            self.transport_messages = transport_messages
        if users is not None:
            self.users = users

    @property
    def alarms(self):
        """Gets the alarms of this SubscriptionUsage.  # noqa: E501


        :return: The alarms of this SubscriptionUsage.  # noqa: E501
        :rtype: int
        """
        return self._alarms

    @alarms.setter
    def alarms(self, alarms):
        """Sets the alarms of this SubscriptionUsage.


        :param alarms: The alarms of this SubscriptionUsage.  # noqa: E501
        :type: int
        """

        self._alarms = alarms

    @property
    def assets(self):
        """Gets the assets of this SubscriptionUsage.  # noqa: E501


        :return: The assets of this SubscriptionUsage.  # noqa: E501
        :rtype: int
        """
        return self._assets

    @assets.setter
    def assets(self, assets):
        """Sets the assets of this SubscriptionUsage.


        :param assets: The assets of this SubscriptionUsage.  # noqa: E501
        :type: int
        """

        self._assets = assets

    @property
    def converters(self):
        """Gets the converters of this SubscriptionUsage.  # noqa: E501


        :return: The converters of this SubscriptionUsage.  # noqa: E501
        :rtype: int
        """
        return self._converters

    @converters.setter
    def converters(self, converters):
        """Sets the converters of this SubscriptionUsage.


        :param converters: The converters of this SubscriptionUsage.  # noqa: E501
        :type: int
        """

        self._converters = converters

    @property
    def customers(self):
        """Gets the customers of this SubscriptionUsage.  # noqa: E501


        :return: The customers of this SubscriptionUsage.  # noqa: E501
        :rtype: int
        """
        return self._customers

    @customers.setter
    def customers(self, customers):
        """Sets the customers of this SubscriptionUsage.


        :param customers: The customers of this SubscriptionUsage.  # noqa: E501
        :type: int
        """

        self._customers = customers

    @property
    def dashboards(self):
        """Gets the dashboards of this SubscriptionUsage.  # noqa: E501


        :return: The dashboards of this SubscriptionUsage.  # noqa: E501
        :rtype: int
        """
        return self._dashboards

    @dashboards.setter
    def dashboards(self, dashboards):
        """Sets the dashboards of this SubscriptionUsage.


        :param dashboards: The dashboards of this SubscriptionUsage.  # noqa: E501
        :type: int
        """

        self._dashboards = dashboards

    @property
    def devices(self):
        """Gets the devices of this SubscriptionUsage.  # noqa: E501


        :return: The devices of this SubscriptionUsage.  # noqa: E501
        :rtype: int
        """
        return self._devices

    @devices.setter
    def devices(self, devices):
        """Sets the devices of this SubscriptionUsage.


        :param devices: The devices of this SubscriptionUsage.  # noqa: E501
        :type: int
        """

        self._devices = devices

    @property
    def dp_storage_days(self):
        """Gets the dp_storage_days of this SubscriptionUsage.  # noqa: E501


        :return: The dp_storage_days of this SubscriptionUsage.  # noqa: E501
        :rtype: int
        """
        return self._dp_storage_days

    @dp_storage_days.setter
    def dp_storage_days(self, dp_storage_days):
        """Sets the dp_storage_days of this SubscriptionUsage.


        :param dp_storage_days: The dp_storage_days of this SubscriptionUsage.  # noqa: E501
        :type: int
        """

        self._dp_storage_days = dp_storage_days

    @property
    def emails(self):
        """Gets the emails of this SubscriptionUsage.  # noqa: E501


        :return: The emails of this SubscriptionUsage.  # noqa: E501
        :rtype: int
        """
        return self._emails

    @emails.setter
    def emails(self, emails):
        """Sets the emails of this SubscriptionUsage.


        :param emails: The emails of this SubscriptionUsage.  # noqa: E501
        :type: int
        """

        self._emails = emails

    @property
    def integrations(self):
        """Gets the integrations of this SubscriptionUsage.  # noqa: E501


        :return: The integrations of this SubscriptionUsage.  # noqa: E501
        :rtype: int
        """
        return self._integrations

    @integrations.setter
    def integrations(self, integrations):
        """Sets the integrations of this SubscriptionUsage.


        :param integrations: The integrations of this SubscriptionUsage.  # noqa: E501
        :type: int
        """

        self._integrations = integrations

    @property
    def js_executions(self):
        """Gets the js_executions of this SubscriptionUsage.  # noqa: E501


        :return: The js_executions of this SubscriptionUsage.  # noqa: E501
        :rtype: int
        """
        return self._js_executions

    @js_executions.setter
    def js_executions(self, js_executions):
        """Sets the js_executions of this SubscriptionUsage.


        :param js_executions: The js_executions of this SubscriptionUsage.  # noqa: E501
        :type: int
        """

        self._js_executions = js_executions

    @property
    def re_executions(self):
        """Gets the re_executions of this SubscriptionUsage.  # noqa: E501


        :return: The re_executions of this SubscriptionUsage.  # noqa: E501
        :rtype: int
        """
        return self._re_executions

    @re_executions.setter
    def re_executions(self, re_executions):
        """Sets the re_executions of this SubscriptionUsage.


        :param re_executions: The re_executions of this SubscriptionUsage.  # noqa: E501
        :type: int
        """

        self._re_executions = re_executions

    @property
    def rule_chains(self):
        """Gets the rule_chains of this SubscriptionUsage.  # noqa: E501


        :return: The rule_chains of this SubscriptionUsage.  # noqa: E501
        :rtype: int
        """
        return self._rule_chains

    @rule_chains.setter
    def rule_chains(self, rule_chains):
        """Sets the rule_chains of this SubscriptionUsage.


        :param rule_chains: The rule_chains of this SubscriptionUsage.  # noqa: E501
        :type: int
        """

        self._rule_chains = rule_chains

    @property
    def scheduler_events(self):
        """Gets the scheduler_events of this SubscriptionUsage.  # noqa: E501


        :return: The scheduler_events of this SubscriptionUsage.  # noqa: E501
        :rtype: int
        """
        return self._scheduler_events

    @scheduler_events.setter
    def scheduler_events(self, scheduler_events):
        """Sets the scheduler_events of this SubscriptionUsage.


        :param scheduler_events: The scheduler_events of this SubscriptionUsage.  # noqa: E501
        :type: int
        """

        self._scheduler_events = scheduler_events

    @property
    def sms(self):
        """Gets the sms of this SubscriptionUsage.  # noqa: E501


        :return: The sms of this SubscriptionUsage.  # noqa: E501
        :rtype: int
        """
        return self._sms

    @sms.setter
    def sms(self, sms):
        """Sets the sms of this SubscriptionUsage.


        :param sms: The sms of this SubscriptionUsage.  # noqa: E501
        :type: int
        """

        self._sms = sms

    @property
    def transport_data_points(self):
        """Gets the transport_data_points of this SubscriptionUsage.  # noqa: E501


        :return: The transport_data_points of this SubscriptionUsage.  # noqa: E501
        :rtype: int
        """
        return self._transport_data_points

    @transport_data_points.setter
    def transport_data_points(self, transport_data_points):
        """Sets the transport_data_points of this SubscriptionUsage.


        :param transport_data_points: The transport_data_points of this SubscriptionUsage.  # noqa: E501
        :type: int
        """

        self._transport_data_points = transport_data_points

    @property
    def transport_messages(self):
        """Gets the transport_messages of this SubscriptionUsage.  # noqa: E501


        :return: The transport_messages of this SubscriptionUsage.  # noqa: E501
        :rtype: int
        """
        return self._transport_messages

    @transport_messages.setter
    def transport_messages(self, transport_messages):
        """Sets the transport_messages of this SubscriptionUsage.


        :param transport_messages: The transport_messages of this SubscriptionUsage.  # noqa: E501
        :type: int
        """

        self._transport_messages = transport_messages

    @property
    def users(self):
        """Gets the users of this SubscriptionUsage.  # noqa: E501


        :return: The users of this SubscriptionUsage.  # noqa: E501
        :rtype: int
        """
        return self._users

    @users.setter
    def users(self, users):
        """Sets the users of this SubscriptionUsage.


        :param users: The users of this SubscriptionUsage.  # noqa: E501
        :type: int
        """

        self._users = users

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(SubscriptionUsage, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, SubscriptionUsage):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



#  Copyright 2024. ThingsBoard
#
#  Licensed under the Apache License, Version 2.0 (the "License");
#  you may not use this file except in compliance with the License.
#  You may obtain a copy of the License at
#
#   http://www.apache.org/licenses/LICENSE-2.0
#
#  Unless required by applicable law or agreed to in writing, software
#  distributed under the License is distributed on an "AS IS" BASIS,
#  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
#  See the License for the specific language governing permissions and
#  limitations under the License.
#

import logging
# Importing models and REST client class from Community Edition version
from tb_rest_client.rest_client_ce import *
from tb_rest_client.rest import ApiException

logging.basicConfig(level=logging.DEBUG,
                    format='%(asctime)s - %(levelname)s - %(module)s - %(lineno)d - %(message)s',
                    datefmt='%Y-%m-%d %H:%M:%S')

# ThingsBoard REST API URL
url = "http://localhost:8080"

# Default Tenant Administrator credentials
username = "tenant@thingsboard.org"
password = "tenant"


def main():
    # Creating the REST client object with context manager to get auto token refresh
    with RestClientCE(base_url=url) as rest_client:
        try:
            # Auth with credentials
            rest_client.login(username=username, password=password)

            # Creating an Asset
            default_asset_profile_id = rest_client.get_default_asset_profile_info().id
            asset = Asset(name="Building 1", label="Building 1",
                          asset_profile_id=default_asset_profile_id)
            asset = rest_client.save_asset(asset)

            logging.info("Asset was created:\n%r\n", asset)

            # Creating a Device
            # Also, you can use default Device Profile:
            # default_device_profile_id = rest_client.get_default_device_profile_info().id
            device_profile = DeviceProfile(name="Thermometer",
                                           profile_data=DeviceProfileData(configuration={"type": "DEFAULT"},
                                                                          transport_configuration={"type": "DEFAULT"}))
            device_profile = rest_client.save_device_profile(device_profile)
            device = Device(name="Thermometer 1", label="Thermometer 1",
                            device_profile_id=device_profile.id)
            device = rest_client.save_device(device)

            logging.info(" Device was created:\n%r\n", device)

            # Creating relations from device to asset
            relation = EntityRelation(_from=asset.id, to=device.id, type="Contains")
            rest_client.save_relation(relation)

            logging.info(" Relation was created:\n%r\n", relation)
        except ApiException as e:
            logging.exception(e)


if __name__ == '__main__':
    main()



# coding: utf-8

"""
    ThingsBoard REST API

     ThingsBoard Professional Edition IoT platform REST API documentation.  # noqa: E501

    OpenAPI spec version: 3.6.2PE
    Contact: info@thingsboard.io
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

#  Copyright 2024. ThingsBoard
#
#  Licensed under the Apache License, Version 2.0 (the "License");
#  you may not use this file except in compliance with the License.
#  You may obtain a copy of the License at
#
#   http://www.apache.org/licenses/LICENSE-2.0
#
#  Unless required by applicable law or agreed to in writing, software
#  distributed under the License is distributed on an "AS IS" BASIS,
#  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
#  See the License for the specific language governing permissions and
#  limitations under the License.

import pprint
import re  # noqa: F401

import six
from tb_rest_client.models.models_pe.event_filter import EventFilter  # noqa: F401,E501

class StatisticsEventFilter(EventFilter):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'not_empty': 'bool',
        'event_type': 'str',
        'server': 'str',
        'min_messages_processed': 'int',
        'max_messages_processed': 'int',
        'min_errors_occurred': 'int',
        'max_errors_occurred': 'int'
    }
    if hasattr(EventFilter, "swagger_types"):
        swagger_types.update(EventFilter.swagger_types)

    attribute_map = {
        'not_empty': 'notEmpty',
        'event_type': 'eventType',
        'server': 'server',
        'min_messages_processed': 'minMessagesProcessed',
        'max_messages_processed': 'maxMessagesProcessed',
        'min_errors_occurred': 'minErrorsOccurred',
        'max_errors_occurred': 'maxErrorsOccurred'
    }
    if hasattr(EventFilter, "attribute_map"):
        attribute_map.update(EventFilter.attribute_map)

    def __init__(self, not_empty=None, event_type=None, server=None, min_messages_processed=None, max_messages_processed=None, min_errors_occurred=None, max_errors_occurred=None, *args, **kwargs):  # noqa: E501
        """StatisticsEventFilter - a model defined in Swagger"""  # noqa: E501
        self._not_empty = None
        self._event_type = None
        self._server = None
        self._min_messages_processed = None
        self._max_messages_processed = None
        self._min_errors_occurred = None
        self._max_errors_occurred = None
        self.discriminator = None
        if not_empty is not None:
            self.not_empty = not_empty
        self.event_type = event_type
        if server is not None:
            self.server = server
        if min_messages_processed is not None:
            self.min_messages_processed = min_messages_processed
        if max_messages_processed is not None:
            self.max_messages_processed = max_messages_processed
        if min_errors_occurred is not None:
            self.min_errors_occurred = min_errors_occurred
        if max_errors_occurred is not None:
            self.max_errors_occurred = max_errors_occurred
        EventFilter.__init__(self, *args, **kwargs)

    @property
    def not_empty(self):
        """Gets the not_empty of this StatisticsEventFilter.  # noqa: E501


        :return: The not_empty of this StatisticsEventFilter.  # noqa: E501
        :rtype: bool
        """
        return self._not_empty

    @not_empty.setter
    def not_empty(self, not_empty):
        """Sets the not_empty of this StatisticsEventFilter.


        :param not_empty: The not_empty of this StatisticsEventFilter.  # noqa: E501
        :type: bool
        """

        self._not_empty = not_empty

    @property
    def event_type(self):
        """Gets the event_type of this StatisticsEventFilter.  # noqa: E501

        String value representing the event type  # noqa: E501

        :return: The event_type of this StatisticsEventFilter.  # noqa: E501
        :rtype: str
        """
        return self._event_type

    @event_type.setter
    def event_type(self, event_type):
        """Sets the event_type of this StatisticsEventFilter.

        String value representing the event type  # noqa: E501

        :param event_type: The event_type of this StatisticsEventFilter.  # noqa: E501
        :type: str
        """
        if event_type is None:
            raise ValueError("Invalid value for `event_type`, must not be `None`")  # noqa: E501
        allowed_values = ["DEBUG_CONVERTER", "DEBUG_INTEGRATION", "DEBUG_RULE_CHAIN", "DEBUG_RULE_NODE", "ERROR", "LC_EVENT", "RAW_DATA", "STATS"]  # noqa: E501
        if event_type not in allowed_values:
            raise ValueError(
                "Invalid value for `event_type` ({0}), must be one of {1}"  # noqa: E501
                .format(event_type, allowed_values)
            )

        self._event_type = event_type

    @property
    def server(self):
        """Gets the server of this StatisticsEventFilter.  # noqa: E501

        String value representing the server name, identifier or ip address where the platform is running  # noqa: E501

        :return: The server of this StatisticsEventFilter.  # noqa: E501
        :rtype: str
        """
        return self._server

    @server.setter
    def server(self, server):
        """Sets the server of this StatisticsEventFilter.

        String value representing the server name, identifier or ip address where the platform is running  # noqa: E501

        :param server: The server of this StatisticsEventFilter.  # noqa: E501
        :type: str
        """

        self._server = server

    @property
    def min_messages_processed(self):
        """Gets the min_messages_processed of this StatisticsEventFilter.  # noqa: E501

        The minimum number of successfully processed messages  # noqa: E501

        :return: The min_messages_processed of this StatisticsEventFilter.  # noqa: E501
        :rtype: int
        """
        return self._min_messages_processed

    @min_messages_processed.setter
    def min_messages_processed(self, min_messages_processed):
        """Sets the min_messages_processed of this StatisticsEventFilter.

        The minimum number of successfully processed messages  # noqa: E501

        :param min_messages_processed: The min_messages_processed of this StatisticsEventFilter.  # noqa: E501
        :type: int
        """

        self._min_messages_processed = min_messages_processed

    @property
    def max_messages_processed(self):
        """Gets the max_messages_processed of this StatisticsEventFilter.  # noqa: E501

        The maximum number of successfully processed messages  # noqa: E501

        :return: The max_messages_processed of this StatisticsEventFilter.  # noqa: E501
        :rtype: int
        """
        return self._max_messages_processed

    @max_messages_processed.setter
    def max_messages_processed(self, max_messages_processed):
        """Sets the max_messages_processed of this StatisticsEventFilter.

        The maximum number of successfully processed messages  # noqa: E501

        :param max_messages_processed: The max_messages_processed of this StatisticsEventFilter.  # noqa: E501
        :type: int
        """

        self._max_messages_processed = max_messages_processed

    @property
    def min_errors_occurred(self):
        """Gets the min_errors_occurred of this StatisticsEventFilter.  # noqa: E501

        The minimum number of errors occurred during messages processing  # noqa: E501

        :return: The min_errors_occurred of this StatisticsEventFilter.  # noqa: E501
        :rtype: int
        """
        return self._min_errors_occurred

    @min_errors_occurred.setter
    def min_errors_occurred(self, min_errors_occurred):
        """Sets the min_errors_occurred of this StatisticsEventFilter.

        The minimum number of errors occurred during messages processing  # noqa: E501

        :param min_errors_occurred: The min_errors_occurred of this StatisticsEventFilter.  # noqa: E501
        :type: int
        """

        self._min_errors_occurred = min_errors_occurred

    @property
    def max_errors_occurred(self):
        """Gets the max_errors_occurred of this StatisticsEventFilter.  # noqa: E501

        The maximum number of errors occurred during messages processing  # noqa: E501

        :return: The max_errors_occurred of this StatisticsEventFilter.  # noqa: E501
        :rtype: int
        """
        return self._max_errors_occurred

    @max_errors_occurred.setter
    def max_errors_occurred(self, max_errors_occurred):
        """Sets the max_errors_occurred of this StatisticsEventFilter.

        The maximum number of errors occurred during messages processing  # noqa: E501

        :param max_errors_occurred: The max_errors_occurred of this StatisticsEventFilter.  # noqa: E501
        :type: int
        """

        self._max_errors_occurred = max_errors_occurred

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(StatisticsEventFilter, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, StatisticsEventFilter):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
